<?php

$LANG = array(
    'organization' => 'Организация',
    'name' => 'Име',
    'website' => 'Уебсайт',
    'work_phone' => 'Телефон',
    'address' => 'Адрес',
    'address1' => 'Улица',
    'address2' => 'Апартамент',
    'city' => 'Град',
    'state' => 'Област',
    'postal_code' => 'Пощенски код',
    'country_id' => 'Държава',
    'contacts' => 'Контакти',
    'first_name' => 'Първо име',
    'last_name' => 'Фамилно име',
    'phone' => 'Телефон',
    'email' => 'Електронна поща',
    'additional_info' => 'Допълнителна информация',
    'payment_terms' => 'Условия за плащане',
    'currency_id' => 'Валута',
    'size_id' => 'Размер на фирма',
    'industry_id' => 'Индустрия',
    'private_notes' => 'Лични бележки',
    'invoice' => 'Фактура',
    'client' => 'Клиент',
    'invoice_date' => 'Дата на фактура',
    'due_date' => 'Крайна дата за плащане',
    'invoice_number' => 'Номер на фактура',
    'invoice_number_short' => 'Фактура №',
    'po_number' => 'номер на пощенска кутия',
    'po_number_short' => 'ПК № ',
    'frequency_id' => 'Колко често',
    'discount' => 'Отстъпка',
    'taxes' => 'Данъци',
    'tax' => 'Данък',
    'item' => 'Продукт',
    'description' => 'Описание',
    'unit_cost' => 'Ед. цена',
    'quantity' => 'Количество',
    'line_total' => 'Обща цена',
    'subtotal' => 'Субтотал',
    'paid_to_date' => 'Платени до момента',
    'balance_due' => 'Остават за плащане',
    'invoice_design_id' => 'Дизайн',
    'terms' => 'Условия',
    'your_invoice' => 'Вашата фактура',
    'remove_contact' => 'Премахни контакт',
    'add_contact' => 'Добави контакт',
    'create_new_client' => 'Създаване на нов клиент',
    'edit_client_details' => 'Редактиране на детайли на клиент',
    'enable' => 'Разреши',
    'learn_more' => 'Научи повече',
    'manage_rates' => 'Управление на тарифите',
    'note_to_client' => 'Бележка за клиент',
    'invoice_terms' => 'Условия на фактура',
    'save_as_default_terms' => 'Запази като условия по подразбиране',
    'download_pdf' => 'Сваляне на PDF',
    'pay_now' => 'Плати сега',
    'save_invoice' => 'Запазване на фактура',
    'clone_invoice' => 'Дублирай във фактура',
    'archive_invoice' => 'Архивиране на фактура',
    'delete_invoice' => 'Изтриване на фактура',
    'email_invoice' => 'Изпращане на фактура',
    'enter_payment' => 'Въведи плащане',
    'tax_rates' => 'Размер на данъци',
    'rate' => 'Размер',
    'settings' => 'Настройки',
    'enable_invoice_tax' => 'Разреши посочването на <b>данък за фактура</b>',
    'enable_line_item_tax' => 'Разреши посочването на <b>данък за всеки ред</b>',
    'dashboard' => 'Табло',
    'dashboard_totals_in_all_currencies_help' => 'Забележка: добавете :link с име ":name" за да покажете сумите в обща базова валута.',
    'clients' => 'Клиенти',
    'invoices' => 'Фактури',
    'payments' => 'Плащания',
    'credits' => 'Кредити',
    'history' => 'История',
    'search' => 'Търсене',
    'sign_up' => 'Регистрация',
    'guest' => 'Гост',
    'company_details' => 'Данни на фирма',
    'online_payments' => 'Онлайн плащания',
    'notifications' => 'Известия',
    'import_export' => 'Импорт | Експорт',
    'done' => 'Готово',
    'save' => 'Запазване',
    'create' => 'Създаване',
    'upload' => 'Качване',
    'import' => 'Импорт',
    'download' => 'Сваляне',
    'cancel' => 'Отказ',
    'close' => 'Затвори',
    'provide_email' => 'Моля въведете валиден email адрес',
    'powered_by' => 'Powered by',
    'no_items' => 'Няма резултати',
    'recurring_invoices' => 'Периодични фактури',
    'recurring_help' => '<p>Автоматично изпращай фактурите на клиентите седмично, на всеки 2 седмици, месечно, четеримесечие или годишно</p>
<p>Използвайте :MONTH, :QUARTER или :YEAR за динамични дати. Може да използвате и елементарна математика, като например :MONTH-1</p>
<p>Примери за динамични стойности във фактури</p>
<ul>
<li>"Фитнес абонамент за месец :MONTH" >> "Фитнес абонамент за месец Юли"</li>
<li>"Aбонамент за :YEAR+1 " >> "Абонамент за 2015"</li>
<li>"Такса за :QUARTER+1" >> Такса за Q2"</li>
</ul>
',
    'recurring_quotes' => 'Периодични Оферти',
    'in_total_revenue' => 'общи приходи',
    'billed_client' => 'таксуван клиент',
    'billed_clients' => 'таксувани клиенти',
    'active_client' => 'активен клиент',
    'active_clients' => 'активни клиенти',
    'invoices_past_due' => 'Просрочени фактури',
    'upcoming_invoices' => 'Предстоящи фактури',
    'average_invoice' => 'Средна стойност на фактура',
    'archive' => 'Архивирай',
    'delete' => 'Изтрий',
    'archive_client' => 'Архивирай клиент',
    'delete_client' => 'Изтрий клиент',
    'archive_payment' => 'Архивирай плащане',
    'delete_payment' => 'Изтрий плащане',
    'archive_credit' => 'Архивирай кредит',
    'delete_credit' => 'Изтрий кредит',
    'show_archived_deleted' => 'Покажи архивирани/изтрити',
    'filter' => 'Филтър',
    'new_client' => 'Нов клиент',
    'new_invoice' => 'Нова фактура',
    'new_payment' => 'Въведи плащане',
    'new_credit' => 'Въведи кредит',
    'contact' => 'Контакт',
    'date_created' => 'Създадено на',
    'last_login' => 'Последно влизане',
    'balance' => 'Баланс',
    'action' => 'Действие',
    'status' => 'Статус',
    'invoice_total' => 'Тотал на фактура',
    'frequency' => 'Честота',
    'range' => 'Интервал',
    'start_date' => 'Начална дата',
    'end_date' => 'Крайна дата',
    'transaction_reference' => 'Основание за превод',
    'method' => 'Начин',
    'payment_amount' => 'Сума на плащане',
    'payment_date' => 'Дата на плащане',
    'credit_amount' => 'Сума на кредита',
    'credit_balance' => 'Баланс на кредита',
    'credit_date' => 'Кредитна Дата',
    'empty_table' => 'Няма данни в таблицата',
    'select' => 'Избери',
    'edit_client' => 'Редактирай клиент',
    'edit_invoice' => 'Редактирай фактура',
    'create_invoice' => 'Създай фактура',
    'enter_credit' => 'Въведете кредит',
    'last_logged_in' => 'За последно влизал',
    'details' => 'Подробности',
    'standing' => 'Отворен',
    'credit' => 'Кредит',
    'activity' => 'Активност',
    'date' => 'Дата',
    'message' => 'Съобщение',
    'adjustment' => 'Настройка',
    'are_you_sure' => 'Сигурен ли сте?',
    'payment_type_id' => 'Начин на плащане',
    'amount' => 'Сума',
    'work_email' => 'Email',
    'language_id' => 'Език',
    'timezone_id' => 'Времева зона',
    'date_format_id' => 'Формат на дати',
    'datetime_format_id' => 'Формат на час и дата',
    'users' => 'Потребители',
    'localization' => 'Локализация',
    'remove_logo' => 'Премахни лого',
    'logo_help' => 'Поддържани формати: JPEG, GIF и PNG',
    'payment_gateway' => 'Платежни посредници',
    'gateway_id' => 'Посредник',
    'email_notifications' => 'Email известия',
    'email_sent' => 'Прати ми email когато фактурата е <b>изпратена</b>',
    'email_viewed' => 'Прати ми email когато фактурата е <b>видяна</b>',
    'email_paid' => 'Прати ми email когато фактурата е <b>платена</b>',
    'site_updates' => 'Обновления на сайта',
    'custom_messages' => 'Собствени Съобщения',
    'default_email_footer' => 'Задай <b>email подпис</b> по подразбиране',
    'select_file' => 'Моля изберете файл',
    'first_row_headers' => 'Използвай първия ред като заглавен',
    'column' => 'Колона',
    'sample' => 'Пример',
    'import_to' => 'Импортирай в',
    'client_will_create' => 'клиент ще бъде създаден',
    'clients_will_create' => 'клиенти ще бъдат създадени',
    'email_settings' => 'Email настройки',
    'client_view_styling' => 'Стилизиране на клиентски изгледи',
    'pdf_email_attachment' => 'Прикачване PDF',
    'custom_css' => 'Персонализиран CSS',
    'import_clients' => 'Импортирай данни на клиента',
    'csv_file' => 'CSV файл',
    'export_clients' => 'Експортирай данни на клиента',
    'created_client' => 'Клиентът е създаден успешно',
    'created_clients' => ':count клиенти са създадени успешно',
    'updated_settings' => 'Настройките са обновени успешно',
    'removed_logo' => 'Логото е премахнато успешно',
    'sent_message' => 'Съобщението е изпратено успешно',
    'invoice_error' => 'Моля изберете клиент и коригирайте грешките',
    'limit_clients' => 'Това действие ще надвиши лимита ви от :count клиента.',
    'payment_error' => 'Имаше проблем при обработването на плащането Ви. Моля опитайте пак по късно.',
    'registration_required' => 'Моля регистрирайте се за да изпратите фактура. ',
    'confirmation_required' => 'Моля потвърдете мейл адреса си, :link за да изпратите наново писмото за потвърждение ',
    'updated_client' => 'Успешно редактиран клиент',
    'archived_client' => 'Успешно архивиран клиент',
    'archived_clients' => 'Успешно архивирани :count клиенти',
    'deleted_client' => 'Успешно изтрит клиент',
    'deleted_clients' => 'Успешно изтрити :count клиенти',
    'updated_invoice' => 'Успешно редактирана фактура',
    'created_invoice' => 'Успешно създадена фактура',
    'cloned_invoice' => 'Успешно направено копие на фактура',
    'emailed_invoice' => 'Успешно изпратена фактура по имейл',
    'and_created_client' => 'и създаден клиент',
    'archived_invoice' => 'Успешно архивирана фактура',
    'archived_invoices' => 'Успешно архивирани :count фактури',
    'deleted_invoice' => 'Успешно изтрита фактура',
    'deleted_invoices' => 'Успешно изтрити :count фактури',
    'created_payment' => 'Успешно създадено плащане',
    'created_payments' => 'Успешно създадени :count плащане(ия)',
    'archived_payment' => 'Успешно архивирано плащане',
    'archived_payments' => 'Успешно архивирани :count плащания',
    'deleted_payment' => 'Успешно изтрито плащане',
    'deleted_payments' => 'Успешно изтрити :count плащания',
    'applied_payment' => 'Успешно направено плащане',
    'created_credit' => 'Успешно създаден кредит',
    'archived_credit' => 'Успешно архивиран кредит',
    'archived_credits' => 'Успешно архивирани :count кредита',
    'deleted_credit' => 'Успешно изтрит кредит',
    'deleted_credits' => 'Успешно изтрити :count кредита',
    'imported_file' => 'Файлът беше успешно импортиран',
    'updated_vendor' => 'Успешно обновен доставчик',
    'created_vendor' => 'Успешно създаден доставчик',
    'archived_vendor' => 'Успешно архивиран доставчик',
    'archived_vendors' => 'Успешно архивирани :count доставчици',
    'deleted_vendor' => 'Успешно изтрит доставчик',
    'deleted_vendors' => 'Успешно изтрити :count доставчици',
    'confirmation_subject' => 'Потвърждаване на Invoice Ninja профил',
    'confirmation_header' => 'Потвърждаване на профил',
    'confirmation_message' => 'Моля посетете линкът по долу за да потвърдите профилът си.',
    'invoice_subject' => 'Нова фактура :number  от :account',
    'invoice_message' => 'За да видите фактурата си за :amount, отворете линка по-долу.',
    'payment_subject' => 'Получено плащане',
    'payment_message' => 'Благодаря за плащането на стойност :amount',
    'email_salutation' => 'Здравейте :name,',
    'email_signature' => 'Поздрави,',
    'email_from' => 'Екипът на Invoice Ninja',
    'invoice_link_message' => 'Зада видите фактурата натиснете линка по-долу.',
    'notification_invoice_paid_subject' => 'Фактура :invoice беше платена от :client',
    'notification_invoice_sent_subject' => 'Фактура :invocie беше изпратена на :client',
    'notification_invoice_viewed_subject' => 'Фактура :invoice беше видяна от :client',
    'notification_invoice_paid' => 'Плащане на стойност :amount беше направено от :client към фактура :invoice.',
    'notification_invoice_sent' => 'Фактура :invoice беше изпратена на :client на стойност :amount',
    'notification_invoice_viewed' => 'Фактура :invoice на стойност :amount беше видяна от :client ',
    'reset_password' => 'Може да смените паролата си като кликнете на този бутон:',
    'secure_payment' => 'Сигурно плащане',
    'card_number' => 'Номер на карта',
    'expiration_month' => 'Месец на изтичане',
    'expiration_year' => 'Година на изтичане',
    'cvv' => 'CVV',
    'logout' => 'Изход',
    'sign_up_to_save' => 'Регистрирайте се за да запазите промените',
    'agree_to_terms' => 'Съгласен съм с :terms',
    'terms_of_service' => 'Условия за ползване',
    'email_taken' => 'Този имейл адрес е вече регистриран',
    'working' => 'Обработва се',
    'success' => 'Усепх',
    'success_message' => 'Успешно се регистрирахте! Моля отворете връзката от имейла за потвърждение за да си потвърдите имейла.',
    'erase_data' => 'Нямате профил, това ще изтрие всички данни',
    'password' => 'Парола',
    'pro_plan_product' => '"Pro" План',
    'pro_plan_success' => 'Благодарим Ви, че избрахте Invoice Ninja Pro! <p/>&nbsp;<br/>
                          <b>Следващи стъпки</b><p/> Фактура беше изпратена на имейл
 адреса свързан с вашият профил.
                          За да отключите всички Pro функционалности, моля следвайте инструкциите 
във фактурата, за да платите за една година Pro план<p/>
                          Не можете да намерите фактурата? Имате нужда от помощ? Ние сме тук за да помогнем!
                          -- Пишете ни на contact@invoiceninja.com',
    'unsaved_changes' => 'Имате незапазени промени',
    'custom_fields' => 'Собствени полета',
    'company_fields' => 'Фирмени полета',
    'client_fields' => 'Клиентски полета',
    'field_label' => 'Етикен на поле',
    'field_value' => 'Стойност на поле',
    'edit' => 'Редактиране',
    'set_name' => 'Въведете името на фирмата Ви',
    'view_as_recipient' => 'Прегледай като получател',
    'product_library' => 'Продуктов каталог',
    'product' => 'Продукт',
    'products' => 'Продукти',
    'fill_products' => 'Автоматично попълвай продукти',
    'fill_products_help' => 'Избирането на продукт автоматично <b>ще попълни описанието и цената</b>',
    'update_products' => 'Автоматично обнови продукти',
    'update_products_help' => 'Промяната на фактура автоматично <b>ще обнови продуктовия каталог</b>',
    'create_product' => 'Нов продукт',
    'edit_product' => 'Редактирай продукт',
    'archive_product' => 'Архивирай продукт',
    'updated_product' => 'Продуктът беше успешно променен',
    'created_product' => 'Продуктът беше успешно създаден',
    'archived_product' => 'Продуктът беше успешно архивиран',
    'pro_plan_custom_fields' => ':link за да получите персонализирани полета, като преминете на Pro план',
    'advanced_settings' => 'Разширени настройки',
    'pro_plan_advanced_settings' => ':link за да получите разширени настройки, като преминете на Pro план',
    'invoice_design' => 'Дизайн на фактура',
    'specify_colors' => 'Избери цветове',
    'specify_colors_label' => 'Изберете цветовете на фактурата',
    'chart_builder' => 'Създател на диаграми',
    'ninja_email_footer' => 'Създаден от: site | Създай. Изпрати. Получи пари.',
    'go_pro' => 'Go Pro',
    'quote' => 'Оферта',
    'quotes' => 'Оферти',
    'quote_number' => 'Номер на оферта',
    'quote_number_short' => 'Оферта №',
    'quote_date' => 'Дата на оферта',
    'quote_total' => 'Обща стойност на офертата',
    'your_quote' => 'Вашата оферта',
    'total' => 'Общо',
    'clone' => 'Копирай',
    'new_quote' => 'Нова оферта',
    'create_quote' => 'Създай Оферта',
    'edit_quote' => 'Редактирай Оферта',
    'archive_quote' => 'Архивирай Оферта',
    'delete_quote' => 'Изтрий Оферта',
    'save_quote' => 'Запази Оферта',
    'email_quote' => 'Изпрати оферта по имейл',
    'clone_quote' => 'Копирай като Оферта',
    'convert_to_invoice' => 'Конвертирай като Фактура',
    'view_invoice' => 'Прегледай Фактура',
    'view_client' => 'Прегледай Клиент',
    'view_quote' => 'Прегледай Оферта',
    'updated_quote' => 'Успешно обновена Оферта',
    'created_quote' => 'Успешно Създадена Оферта',
    'cloned_quote' => 'Успешно копирана Оферта',
    'emailed_quote' => 'Успешно изпратена Оферта',
    'archived_quote' => 'Успешно архивирана Оферта',
    'archived_quotes' => 'Успешно архивирани :count Оферти',
    'deleted_quote' => 'Успешно изтрита Оферта',
    'deleted_quotes' => 'Успешно изтрити :count Оферти',
    'converted_to_invoice' => 'Успешно конвертиране на Оферта към Фактура',
    'quote_subject' => 'Нова Оферта :number от :account',
    'quote_message' => 'За да прегледате вашата оферта на стойност :amount, посетете линкът по долу.',
    'quote_link_message' => 'За да прегледате вашата клиентска оферта  посетете линкът по долу.',
    'notification_quote_sent_subject' => 'Оферта :invoice беше изпратена до :client',
    'notification_quote_viewed_subject' => 'Оферта :invoice беше видяна от :client',
    'notification_quote_sent' => 'Оферта :invoice на стойност :amount беше изпратена до :client.',
    'notification_quote_viewed' => ':client прегледа оферта :invoice на стойност :amount',
    'session_expired' => 'Сесията Ви е изтекла.',
    'invoice_fields' => 'Полета на фактурата',
    'invoice_options' => 'Опции на фактурата',
    'hide_paid_to_date' => 'Скрий "Изплатено до момента"',
    'hide_paid_to_date_help' => 'Покажи "Изплатено до момента" във фактурите, след като е получено плащане. ',
    'charge_taxes' => 'Начисли данъци',
    'user_management' => 'Управление на потребителите',
    'add_user' => 'Добави Потребител',
    'send_invite' => 'Изпрати покана',
    'sent_invite' => 'Успешно изпратена покана',
    'updated_user' => 'Успешно обновен потребител',
    'invitation_message' => 'Бяхте поканен от :invitator',
    'register_to_add_user' => 'Моля регистрирайте се за да добавите потребител',
    'user_state' => 'Щат',
    'edit_user' => 'Редактирай Потребител',
    'delete_user' => 'Изтрий Потребител',
    'active' => 'Активен',
    'pending' => 'Очаквано',
    'deleted_user' => 'Успешно изтрит Потребител',
    'confirm_email_invoice' => 'Сигурни ли сте, че искате да изпратите тази фактура по имейл?',
    'confirm_email_quote' => 'Сигурни ли сте, че искате да изпратите тази оферта по имейл?',
    'confirm_recurring_email_invoice' => ':confirm_email_invoice',
    'confirm_recurring_email_invoice_not_sent' => 'Сигурни ли сте, че искате да стартирате периодичното стартиране?',
    'cancel_account' => 'Изтрий Профил',
    'cancel_account_message' => 'ВНИМАНИЕ: Това действие ще изтрие перманентно вашият профил и данните в него. След това данните няма как да бъдат възстановени. ',
    'go_back' => 'Назад',
    'data_visualizations' => 'Визуализация на данни',
    'sample_data' => 'Показани са примерни данни',
    'hide' => 'Скрий',
    'new_version_available' => 'Налична е нова версия на :releases_link. Вие използвате v:user_version, последната е v:latest_version',
    'invoice_settings' => 'Настройки на Фактурите',
    'invoice_number_prefix' => 'Префикс на номера на фактурите',
    'invoice_number_counter' => 'Следващ номер на фактура',
    'quote_number_prefix' => 'Префикс на номера на офертите',
    'quote_number_counter' => 'Следващ номер на оферта',
    'share_invoice_counter' => 'Споделен номер на фактурите',
    'invoice_issued_to' => 'Фактура издадена на',
    'invalid_counter' => 'За да се избегне възможен конфликт, моля въведете префикс за номер на фактура или за номер на оферта',
    'mark_sent' => 'Маркирай като изпратена',
    'gateway_help_1' => ':link за регистрация в Authorize.net.',
    'gateway_help_2' => ':link за регистрация в Authorize.net.',
    'gateway_help_17' => ':link за получаване на PayPal API signature.',
    'gateway_help_27' => ':link за регистрация в 2Checkout.com. За да осигурите проследяване на плащанията въведете :complete_link като "redirect URL" в менюто Account > Site Management в портала на 2Checkout.',
    'gateway_help_60' => ':link за създаване на профил в WePay.',
    'more_designs' => 'Още дизайни',
    'more_designs_title' => 'Допълнителни дизайни на фактурите',
    'more_designs_cloud_header' => 'Ъпгрейд към версия Pro за повече дизайни на фактури',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Купи',
    'bought_designs' => 'Успешно добавени допълнителни дизайни на фактурите',
    'sent' => 'Изпратена',
    'vat_number' => 'ДДС Номер',
    'timesheets' => 'Графици',
    'payment_title' => 'Въведете своя адрес за фактуриране и информация за кредитна карта',
    'payment_cvv' => '*Това е номерът от 3-4 цифри на гърба на кредитната карта',
    'payment_footer1' => '*Адресът за фактуриране трябва да съвпада с адреса на кредитната карта.',
    'payment_footer2' => '*Моля, натиснете "PAY NOW" само веднъж - транзакцията може да отнеме до 1 минута за обработка.',
    'id_number' => 'ЕИК/Булстат',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'Успешно активиране на лиценз White label.',
    'white_labeled' => 'White labeled',
    'restore' => 'Възтанови',
    'restore_invoice' => 'Възтанови Фактура',
    'restore_quote' => 'Възтанови Оферта',
    'restore_client' => 'Възтанови Клиент',
    'restore_credit' => 'Възтанови Кредит',
    'restore_payment' => 'Възтанови Плащане',
    'restored_invoice' => 'Успешно възстановена фактура',
    'restored_quote' => 'Успешно възстановена Оферта',
    'restored_client' => 'Успешно възстановен Клиент',
    'restored_payment' => 'Успешно възстановенo Плащане',
    'restored_credit' => 'Успешно възстановен кредит',
    'reason_for_canceling' => 'Помогнете ни да подобрим сайта си като ни кажете, защо напускате.',
    'discount_percent' => 'Процент',
    'discount_amount' => 'Сума',
    'invoice_history' => 'История на фактурите',
    'quote_history' => 'История на офертите',
    'current_version' => 'Текуща версия',
    'select_version' => 'Избери версия',
    'view_history' => 'Прегледай историята',
    'edit_payment' => 'Редактирай Плащане',
    'updated_payment' => 'Успешно обновено Плащане',
    'deleted' => 'изтрита',
    'restore_user' => 'Възстанови Потребител',
    'restored_user' => 'Успешно възстановен Потребител',
    'show_deleted_users' => 'Покажи изтрити потребители',
    'email_templates' => 'Шаблони на имейли',
    'invoice_email' => 'Имейл за фактура',
    'payment_email' => 'Имейл за плащане',
    'quote_email' => 'Имейл за оферта',
    'reset_all' => 'Нулиране на всички',
    'approve' => 'Одобрение',
    'token_billing_type_id' => 'Token за плащане',
    'token_billing_help' => 'Запазване на детайлите за плащане с WePay, Stripe, Braintree или GoCardless.',
    'token_billing_1' => 'Неактивно',
    'token_billing_2' => 'Opt-in - чекбоксът се показва, но не е селектиран',
    'token_billing_3' => 'Opt-in - чекбоксът се показва и е селектиран',
    'token_billing_4' => 'Винаги',
    'token_billing_checkbox' => 'Запазване на детайлите на кредитната карта',
    'view_in_gateway' => 'Преглед в :gateway',
    'use_card_on_file' => 'Използване на записаната карта',
    'edit_payment_details' => 'Редактиране на данните за плащане',
    'token_billing' => 'Запазване на данните на картата',
    'token_billing_secure' => 'Данните са сигурно съхранени от :link',
    'support' => 'Поддръжка',
    'contact_information' => 'Информация за контакт',
    '256_encryption' => '256-битово криптиране',
    'amount_due' => 'Сума в падеж',
    'billing_address' => 'Адрес за фактуриране',
    'billing_method' => 'Метод на плащане',
    'order_overview' => 'Преглед на поръчката',
    'match_address' => '*Адресът трябва да съвпада с адреса асоцииран с кредитната карта.',
    'click_once' => '*Моля, натиснете "PAY NOW" само веднъж - транзакцията може да отнеме до 1 минута за обработка.',
    'invoice_footer' => 'Футър на фактурата',
    'save_as_default_footer' => 'Запази като футър по подразбиране',
    'token_management' => 'Управление на токъни',
    'tokens' => 'Токъни',
    'add_token' => 'Добавяне на токън',
    'show_deleted_tokens' => 'Показване на изтритите токъни',
    'deleted_token' => 'Успешно изтрит токън',
    'created_token' => 'Успешно създаден токън',
    'updated_token' => 'Успешно актуализиран токън',
    'edit_token' => 'Редакция на токън',
    'delete_token' => 'Изтриване на токън',
    'token' => 'Токън',
    'add_gateway' => 'Добавяне на Gateway',
    'delete_gateway' => 'Изтриване на Gateway',
    'edit_gateway' => 'Редакция на Gateway',
    'updated_gateway' => 'Успешно актуализиран Gateway',
    'created_gateway' => 'Успешно създаден Gateway',
    'deleted_gateway' => 'Успешно изтрит Gateway',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Кредитна карта',
    'change_password' => 'Промяна на парола',
    'current_password' => 'Настояща парола',
    'new_password' => 'Нова парола',
    'confirm_password' => 'Потвърждение на паролата',
    'password_error_incorrect' => 'Настоящата парола е грешна.',
    'password_error_invalid' => 'Новата парола не е валидна.',
    'updated_password' => 'Успешно сменена парола',
    'api_tokens' => 'API токъни',
    'users_and_tokens' => 'Потребители & токъни',
    'account_login' => 'Вход в профила',
    'recover_password' => 'Възстановяване на парола',
    'forgot_password' => 'Забравена парола?',
    'email_address' => 'Имейл адрес',
    'lets_go' => 'Да започваме!',
    'password_recovery' => 'Възстановяване на парола',
    'send_email' => 'Изпращане на имейл',
    'set_password' => 'Задаване на парола',
    'converted' => 'Конвертирано',
    'email_approved' => 'Прати ми имейл, когато офертата <b>одобрена</b>',
    'notification_quote_approved_subject' => 'Оферта :invoice е одобрена от :client',
    'notification_quote_approved' => 'Клиентът :client одобри оферта :invoice на стойност :amount.',
    'resend_confirmation' => 'Повторно изпращане на имейл за потвърждение',
    'confirmation_resent' => 'Имейлът за потвърждение беше изпратен отново',
    'gateway_help_42' => ':link за регистрация в BitPay.<br/>Забележка: използвайте Legacy API Key, а не API token.',
    'payment_type_credit_card' => 'Кредитна карта',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Knowledge Base',
    'partial' => 'Частично плащане / депозит',
    'partial_remaining' => ':partial от :balance',
    'more_fields' => 'Още полета',
    'less_fields' => 'По-малко полета',
    'client_name' => 'Име на клиент',
    'pdf_settings' => 'PDF настройки',
    'product_settings' => 'Настройки на продукти',
    'auto_wrap' => 'Auto Line Wrap',
    'duplicate_post' => 'Внимание: предишната страница е изпратена два пъти. Второто изпращане е игнорирано.',
    'view_documentation' => 'Вижте документацията',
    'app_title' => 'Безплатно Open-Source онлайн фактуриране',
    'app_description' => 'Invoice Ninja е безплатно решение с отворен код за фактуриране и плащане. С Invoice Ninja лесно създавате и изпращате фактури от всяко устройство с достъп до интернет. Клиентите Ви могат да отпечатат фактурите, да ги изтефлят в pdf формат и дори да Ви платят онлайн в системата.',
    'rows' => 'редове',
    'www' => 'www',
    'logo' => 'Лого',
    'subdomain' => 'Subdomain',
    'provide_name_or_email' => 'Моля, въведете име или имейл',
    'charts_and_reports' => 'Графики и справки',
    'chart' => 'Графика',
    'report' => 'Справка',
    'group_by' => 'Групиране по',
    'paid' => 'Платено',
    'enable_report' => 'Справка',
    'enable_chart' => 'Графика',
    'totals' => 'Общи суми',
    'run' => 'Старт',
    'export' => 'Експорт',
    'documentation' => 'Документация',
    'zapier' => 'Zapier',
    'recurring' => 'Периодично',
    'last_invoice_sent' => 'Последна фактура изпратена на :date',
    'processed_updates' => 'Успешно завършен ъпдейт',
    'tasks' => 'Задачи',
    'new_task' => 'Нова задача',
    'start_time' => 'Начало',
    'created_task' => 'Успешно създадена задача',
    'updated_task' => 'Успешно актуализирана задача',
    'edit_task' => 'Редакция на задача',
    'clone_task' => 'Клониране на Задача',
    'archive_task' => 'Архивиране на задача',
    'restore_task' => 'Възстановяване на задача',
    'delete_task' => 'Изтриване на задача',
    'stop_task' => 'Спиране на задача',
    'time' => 'Време',
    'start' => 'Старт',
    'stop' => 'Стоп',
    'now' => 'Сега',
    'timer' => 'Таймер',
    'manual' => 'Ръчно',
    'date_and_time' => 'Дата и час',
    'second' => 'секунда',
    'seconds' => 'секунди',
    'minute' => 'минута',
    'minutes' => 'минути',
    'hour' => 'час',
    'hours' => 'Часове',
    'task_details' => 'Детайли на задачата',
    'duration' => 'Продължителност',
    'time_log' => 'Лог за време',
    'end_time' => 'Край',
    'end' => 'Край',
    'invoiced' => 'Фактурирано',
    'logged' => 'Логвано',
    'running' => 'Стартирано',
    'task_error_multiple_clients' => 'Задачата не може да бъде присвоена на различни клиенти',
    'task_error_running' => 'Моля, първо спрете стартираните задачи',
    'task_error_invoiced' => 'Задачите вече са фактурирани',
    'restored_task' => 'Успешно възстановена задача',
    'archived_task' => 'Успешно архивирана задача',
    'archived_tasks' => 'Успешно архивирани :count задачи',
    'deleted_task' => 'Успешно изтрита задача',
    'deleted_tasks' => 'Успешно изтрити :count задачи',
    'create_task' => 'Нова задача',
    'stopped_task' => 'Успешно спряна задача',
    'invoice_task' => 'Фактуриране на задача',
    'invoice_labels' => 'Етикети на фактурата',
    'prefix' => 'Префикс',
    'counter' => 'Брояч',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link за вход в Dwolla',
    'partial_value' => 'Трябва да бъде повече от 0 и по-малко от общата стойност.',
    'more_actions' => 'Още',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Upgrade Now!',
    'pro_plan_feature1' => 'Създаване на неограничен брой клиенти',
    'pro_plan_feature2' => 'Достъп до 10 красиви дизайна на фактури',
    'pro_plan_feature3' => 'Персонализиран URL - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Премахване на "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Достъп на множество потребители и следене на дейността',
    'pro_plan_feature6' => 'Създаване на оферти и проформа фактури',
    'pro_plan_feature7' => 'Персонализиране на заглавията на полетата на фактурите и номерирането',
    'pro_plan_feature8' => 'Възможност за орикачване на PDF файлове към имейлите до клиентите',
    'resume' => 'Продължаване',
    'break_duration' => 'Прекратяване',
    'edit_details' => 'Редакция на детайлите',
    'work' => 'Работа',
    'timezone_unset' => 'Миля, :link за да зададете часова зона',
    'click_here' => 'натиснете тук',
    'email_receipt' => 'Изпращане на имейл за плащане към клиента',
    'created_payment_emailed_client' => 'Успешно създадено плащане и изпратен имейл към клиента',
    'add_company' => 'Добавяне на фирма',
    'untitled' => 'Без заглавие',
    'new_company' => 'Нова фирма',
    'associated_accounts' => 'Успешно свързани профили',
    'unlinked_account' => 'Успешно разделени профили',
    'login' => 'Вход',
    'or' => 'или',
    'email_error' => 'Проблем при изпращането на имейла',
    'confirm_recurring_timing' => 'Забележка: Имейлите се изпращат на кръгъл час.',
    'confirm_recurring_timing_not_sent' => 'Забележка: Фактурите се създават на кръгъл час.',
    'payment_terms_help' => 'Задава <b>падеж на фактурата</b> по подразбиране',
    'unlink_account' => 'Разделяне на профили',
    'unlink' => 'Разделяне',
    'show_address' => 'Показване на адрес',
    'show_address_help' => 'Изискване клиента да предостави адрес за фактуриране',
    'update_address' => 'Актуализация на адреса',
    'update_address_help' => 'Актуализация на адреса на клиента с предоставените данни',
    'times' => 'Време',
    'set_now' => 'Сега',
    'dark_mode' => 'Тъмен режим',
    'dark_mode_help' => 'Тъмен фон за страничните колони',
    'add_to_invoice' => 'Добавяне към фактура :invoice',
    'create_new_invoice' => 'Създаване на нова фактура',
    'task_errors' => 'Моля, коригирайте припокриващите се интервали',
    'from' => 'От',
    'to' => 'До',
    'font_size' => 'Размер на шрифта',
    'primary_color' => 'Основен цвят',
    'secondary_color' => 'Допълнителен цвят',
    'customize_design' => 'Персонализиране на дизайна',
    'content' => 'Съдържание',
    'styles' => 'Стилове',
    'defaults' => 'По подразбиране',
    'margins' => 'Граници',
    'header' => 'Хедър',
    'footer' => 'Футър',
    'custom' => 'Custom',
    'invoice_to' => 'Фактура до',
    'invoice_no' => 'Фактура номер',
    'quote_no' => 'Оферта номер',
    'recent_payments' => 'Последни плащания',
    'outstanding' => 'Оставащи',
    'manage_companies' => 'Управление на фирми',
    'total_revenue' => 'Общо приходи',
    'current_user' => 'Настоящ потребител',
    'new_recurring_invoice' => 'Нова периодична фактура',
    'recurring_invoice' => 'Периодична фактура',
    'new_recurring_quote' => 'Нова периодична оферта',
    'recurring_quote' => 'Периодична оферта',
    'recurring_too_soon' => 'Твърде рано е за създаване на следващата периодична фактура, по график е предвидена за :date',
    'created_by_invoice' => 'Създадено от :invoice',
    'primary_user' => 'Основен потребител',
    'help' => 'Помощ',
    'customize_help' => '<p>Ние използваме :pdfmake_link за декларативно дефиниране на дизайна на фактурите. Инструментът pdfmake :playground_link осигурява чудесен начин да видите библиотеката в действие.</p>
                        <p>Ако се нуждаете от помощ, задайте въпрос в нашия :forum_link с дизайна, който използвайте.</p>',
    'playground' => 'playground',
    'support_forum' => 'Форум за поддръжка',
    'invoice_due_date' => 'Падеж',
    'quote_due_date' => 'Валидна до',
    'valid_until' => 'Валидна до',
    'reset_terms' => 'Нулиране на условията',
    'reset_footer' => 'Нулиране на футър',
    'invoice_sent' => ':count изпратена фактура',
    'invoices_sent' => ':count изпратени фактури',
    'status_draft' => 'Чернова',
    'status_sent' => 'Изпратени',
    'status_viewed' => 'Видяни',
    'status_partial' => 'Частично платени',
    'status_paid' => 'Платени',
    'status_unpaid' => 'Неплатени',
    'status_all' => 'Всички',
    'show_line_item_tax' => 'Показване на <b>данъка по редове</b>',
    'iframe_url' => 'Сайт',
    'iframe_url_help1' => 'Копирайте този код в страница на Вашия сайт.',
    'iframe_url_help2' => 'Можете да тествате тази функционалност като изберете \'Виж като получател\' за определена фактура.',
    'auto_bill' => 'Автоматично фактуриране',
    'military_time' => '24 часово време',
    'last_sent' => 'Последно изпратени',
    'reminder_emails' => 'Напомняния по имейл',
    'quote_reminder_emails' => 'Имейли с напомняне за оферти',
    'templates_and_reminders' => 'Шаблони и напомняния',
    'subject' => 'Относно',
    'body' => 'Основен текст',
    'first_reminder' => 'Първо напомняне',
    'second_reminder' => 'Второ напомняне',
    'third_reminder' => 'Трето напомняне',
    'num_days_reminder' => 'Дни след падежа',
    'reminder_subject' => 'Напомняне: Фактура :invoice от :account',
    'reset' => 'Нулиране',
    'invoice_not_found' => 'Фактурата не е налична',
    'referral_program' => 'Referral Program',
    'referral_code' => 'Referral URL',
    'last_sent_on' => 'Последно изпратена: :date',
    'page_expire' => 'Тази страница скоро ще изтече, :click_here за да продължите',
    'upcoming_quotes' => 'Предстоящи оферти',
    'expired_quotes' => 'Изтекли оферти',
    'sign_up_using' => 'Вход чрез',
    'invalid_credentials' => 'Въведените данни не зъвпадат със записаните при нас',
    'show_all_options' => 'Показване на всички опции',
    'user_details' => 'Данни за потребителя',
    'oneclick_login' => 'Свързан профил',
    'disable' => 'Деактивиране',
    'invoice_quote_number' => 'Номерация на фактури и оферти',
    'invoice_charges' => 'Допълнителни такси за фактури',
    'notification_invoice_bounced' => 'Не успяхме да доставим фактура :invoice на :contact.',
    'notification_invoice_bounced_subject' => 'Невъзможна доставка на фактура :invoice',
    'notification_quote_bounced' => 'Не успяхме да доставим оферта :invoice на :contact.',
    'notification_quote_bounced_subject' => 'Невъзможна доставка на оферта :invoice',
    'custom_invoice_link' => 'Персонален линк за фактура',
    'total_invoiced' => 'Общо фактурирано',
    'open_balance' => 'Отворен баланс',
    'verify_email' => 'Моля, отворете линка от имейла за потвърждение за да верифицирате своя имейл адрес.',
    'basic_settings' => 'Основни настройки',
    'pro' => 'Pro',
    'gateways' => 'Портали за плащане',
    'next_send_on' => 'Следващо изпращане: :date',
    'no_longer_running' => 'Тази фактура не е заложена в графика',
    'general_settings' => 'Общи настройки',
    'customize' => 'Персонализиране',
    'oneclick_login_help' => 'Сържете профил за вход без парола',
    'referral_code_help' => 'Спечелете пари като споделите нашето приложение онлайн',
    'enable_with_stripe' => 'Активиране | Изисква Stripe',
    'tax_settings' => 'Настройки за данък',
    'create_tax_rate' => 'Добавяне на данъчна ставка',
    'updated_tax_rate' => 'Успешно актуализирана данъчна ставка',
    'created_tax_rate' => 'Успешно създадена данъчна ставка',
    'edit_tax_rate' => 'Редакция на данъчна ставка',
    'archive_tax_rate' => 'Архивиране на данъчна ставка',
    'archived_tax_rate' => 'Успешно архивиране на данъчна ставка',
    'default_tax_rate_id' => 'Данъчна ставка по подразбиране',
    'tax_rate' => 'Данъчна ставка',
    'recurring_hour' => 'Периодичен час',
    'pattern' => 'Шаблон',
    'pattern_help_title' => 'Помощ за шаблон',
    'pattern_help_1' => 'Създайте персонализирана номерация като заложите шаблон',
    'pattern_help_2' => 'Налични променливи:',
    'pattern_help_3' => 'Например, :example ще се превърне в :value',
    'see_options' => 'Вижте опциите',
    'invoice_counter' => 'Брояч фактури',
    'quote_counter' => 'Брояч оферти',
    'type' => 'Тип',
    'activity_1' => ':user зъздаде клиент :client',
    'activity_2' => ':user архивира клиент :client',
    'activity_3' => ':user изтри клиент :client',
    'activity_4' => ':user създаде фактура :invoice',
    'activity_5' => ':user актуализира фактура :invoice',
    'activity_6' => ':user изпрати фактура :invoice, към :client, на :contact',
    'activity_7' => ':contact прегледа фактура :invoice, към :client',
    'activity_8' => ':user архивира фактура :invoice',
    'activity_9' => ':user изтри фактура :invoice',
    'activity_10' => ':contact въведе плащане :payment в размер на :payment_amount по фактура :invoice за :client',
    'activity_11' => ':user актуализира плащане :payment',
    'activity_12' => ':user архивира плащане :payment',
    'activity_13' => ':user изтри плащане :payment',
    'activity_14' => ':user въведе :credit credit',
    'activity_15' => ':user актуализира :credit credit',
    'activity_16' => ':user архивира :credit credit',
    'activity_17' => ':user изтри кредит :credit',
    'activity_18' => ':user създаде оферта :quote',
    'activity_19' => ':user актуализира оферта :quote',
    'activity_20' => ':user изпрати оферта :quote, към :client, на :contact',
    'activity_21' => ':contact прегледа оферта :quote',
    'activity_22' => ':user архивира оферта :quote',
    'activity_23' => ':user изтри оферта :quote',
    'activity_24' => ':user възстанови оферта :quote',
    'activity_25' => ':user възстанови фактура :invoice',
    'activity_26' => ':user възстанови клиент :client',
    'activity_27' => ':user възстанови плащане :payment',
    'activity_28' => ':user възстанови кредит :credit',
    'activity_29' => ':contact одобри оферта :quote, към :client',
    'activity_30' => ':user създаде доставчик :vendor',
    'activity_31' => ':user архивира доставчик :vendor',
    'activity_32' => ':user изтри доставчик :vendor',
    'activity_33' => ':user възстанови доставчик :vendor',
    'activity_34' => ':user създаде покупка :expense',
    'activity_35' => ':user архивира покупка :expense',
    'activity_36' => ':user изтри покупка :expense',
    'activity_37' => ':user възстанови покупка :expense',
    'activity_42' => ':user създаде задача :task',
    'activity_43' => ':user актуализира задача :task',
    'activity_44' => ':user архивира задача :task',
    'activity_45' => ':user изтри задача :task',
    'activity_46' => ':user възстанови задача :task',
    'activity_47' => ':user актуализира покупка :expense',
    'activity_48' => ':user актуализира тикет :ticket',
    'activity_49' => ':user затвори тикет :ticket',
    'activity_50' => ':user обедини тикет :ticket',
    'activity_51' => ':user раздели тикет :ticket',
    'activity_52' => ':contact отвори тикет :ticket',
    'activity_53' => ':contact отново отвори тикет :ticket',
    'activity_54' => ':user отново отвори :ticket',
    'activity_55' => ':contact отговори на тикет :ticket',
    'activity_56' => ':user прегледа тикет :ticket',

    'payment' => 'Плащане',
    'system' => 'Система',
    'signature' => 'Подпис в имейл',
    'default_messages' => 'Съобщения по подразбиране',
    'quote_terms' => 'Условия на оферта',
    'default_quote_terms' => 'Условия на оферта по подразбиране',
    'default_invoice_terms' => 'Условия на фактура по подразбиране',
    'default_invoice_footer' => 'Футър на фактура по подразбиране',
    'quote_footer' => 'Футър на оферта',
    'free' => 'Безплатно',
    'quote_is_approved' => 'Успешно потвърждение',
    'apply_credit' => 'Прилагане на кредит',
    'system_settings' => 'Системни настройки',
    'archive_token' => 'Архивиране на токен',
    'archived_token' => 'Успешно архивиран токен',
    'archive_user' => 'Архивиране на потребител',
    'archived_user' => 'Успешно архивиране на потребител',
    'archive_account_gateway' => 'Изтриване на портал',
    'archived_account_gateway' => 'Успешно архивиране на портал',
    'archive_recurring_invoice' => 'Архивиране на периодична фактура',
    'archived_recurring_invoice' => 'Успешно архивиране на периодична фактура',
    'delete_recurring_invoice' => 'зтриване на периодична фактура',
    'deleted_recurring_invoice' => 'Успешно изтриване на периодична фактура',
    'restore_recurring_invoice' => 'Възстановяване на периодична фактура',
    'restored_recurring_invoice' => 'Успешно възстановяване на периодична фактура',
    'archive_recurring_quote' => 'Архивиране на периодична оферта',
    'archived_recurring_quote' => 'Успешно архивиране на периодична оферта',
    'delete_recurring_quote' => 'Изтриване на периодична оферта',
    'deleted_recurring_quote' => 'Успешно изтриване на периодична оферта',
    'restore_recurring_quote' => 'Възстановяване на периодична оферта',
    'restored_recurring_quote' => 'спешно възстановяване на периодична оферта',
    'archived' => 'Архив',
    'untitled_account' => 'Фирма без име',
    'before' => 'Преди',
    'after' => 'След',
    'reset_terms_help' => 'Връщане към условията по подразбиране',
    'reset_footer_help' => 'Връщане към футъра по подразбиране',
    'export_data' => 'Експорт на данни',
    'user' => 'Потребител',
    'country' => 'Държава',
    'include' => 'Включване',
    'logo_too_large' => 'Размерът на Вашето лого е :size. За по-добра производителност на PDF файла предлагаме да качите изображение по-малко от 200KB.',
    'import_freshbooks' => 'Импорт от FreshBooks',
    'import_data' => 'Импорт на данни',
    'source' => 'Източник',
    'csv' => 'CSV',
    'client_file' => 'Файл с клиентски данни',
    'invoice_file' => 'Файл с фактури',
    'task_file' => 'Файл със задачи',
    'no_mapper' => 'Невалидна структура на файл',
    'invalid_csv_header' => 'Невалиден CSV хедър',
    'client_portal' => 'Клиентски портал',
    'admin' => 'Администриране',
    'disabled' => 'Неактивно',
    'show_archived_users' => 'Показване на архивирани потребители',
    'notes' => 'Забележки',
    'invoice_will_create' => 'Фактурата ще бъде създадена',
    'invoices_will_create' => 'Фактурите ще бъдат създадени',
    'failed_to_import' => 'Следните записи не могат да бъдат импортирани, защото вече съществуват или липсват задължителни полета с данни.',
    'publishable_key' => 'Ключ за публикуване',
    'secret_key' => 'Таен ключ',
    'missing_publishable_key' => 'Въведете своя Stripe ключ за публикуване за подобряване на процеса на плащане',
    'email_design' => 'Дизайн на имейл',
    'due_by' => 'Дължимо до :date',
    'enable_email_markup' => 'Активиране на Markup',
    'enable_email_markup_help' => 'Направете плащането към Вас по-лесно за клиентите си като добавите в имейлите си schema.org markup.',
    'template_help_title' => 'Помощ за шаблоните',
    'template_help_1' => 'Налични променливи:',
    'email_design_id' => 'Стилове на имейла',
    'email_design_help' => 'Направете имейлите си да изглеждат по-професионално с HTML layout.',
    'plain' => 'Изчистено',
    'light' => 'Светло',
    'dark' => 'Тъмно',
    'industry_help' => 'Използва се за сравнение със средните стойности за фирми с подомер размер и предмет на дейност.',
    'subdomain_help' => 'Заложете subdomain или показвайте фактурите на собствения си сайт.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Въведете префикс или използвайте персонализиран шаблон за генериране на номер на фактура.',
    'quote_number_help' => 'Въведете префикс или използвайте персонализиран шаблон за генериране на номер на оферта.',
    'custom_client_fields_helps' => 'Добавете поле при създаване на клиент и ако желате включете етикета и стойността му в PDF документа.',
    'custom_account_fields_helps' => 'Добавете етикет и стойност към секцията с данните на фирмата в PDF документа.',
    'custom_invoice_fields_helps' => 'Добавете поле при създаване на фактура и ако желате включете етикета и стойността му в PDF документа. ',
    'custom_invoice_charges_helps' => 'Добавете поле при създаване на фактура и ако желате включете таксата в стойността на фактурата. ',
    'token_expired' => 'Валидиращият токън е изтекъл. Моля, опитайте отново.',
    'invoice_link' => 'Линк за фактура',
    'button_confirmation_message' => 'Кликнете, за да потвърдите имейл адреса си.',
    'confirm' => 'Потвърждение',
    'email_preferences' => 'Предпочитания за имейли',
    'created_invoices' => 'Успешно създадена/и :count фактура/и',
    'next_invoice_number' => 'Следващият номер на фактура е :number.',
    'next_quote_number' => 'Следващият номер на оферта е :number.',
    'days_before' => 'дни преди',
    'days_after' => 'дни след',
    'field_due_date' => 'падеж',
    'field_invoice_date' => 'Дата на фактура',
    'schedule' => 'График',
    'email_designs' => 'Дизайн на имейли',
    'assigned_when_sent' => 'Присвоен при изпращане',
    'white_label_purchase_link' => 'Купете лиценз White label',
    'expense' => 'Разход',
    'expenses' => 'Разходи',
    'new_expense' => 'Въведете разход',
    'enter_expense' => 'Въведете разход',
    'vendors' => 'Доставчици',
    'new_vendor' => 'Нов доставчик',
    'payment_terms_net' => 'Нетно',
    'vendor' => 'Доставчик',
    'edit_vendor' => 'Редакция на доставчик',
    'archive_vendor' => 'Архивиране на доставчик',
    'delete_vendor' => 'Изтриване на доставчик',
    'view_vendor' => 'Преглед на доставчик',
    'deleted_expense' => 'Успешно изтрит разход',
    'archived_expense' => 'Успешно архивиран разход',
    'deleted_expenses' => 'Успешно изтрити разходи',
    'archived_expenses' => 'Успешно архивирани разходи',
    'expense_amount' => 'Сума разходи',
    'expense_balance' => 'Баланс разходи',
    'expense_date' => 'Дата разход',
    'expense_should_be_invoiced' => 'Този разход трябва ли да се префактурира?',
    'public_notes' => 'Публични забележки',
    'invoice_amount' => 'Стойност на фактура',
    'exchange_rate' => 'Курс',
    'yes' => 'Да',
    'no' => 'Не',
    'should_be_invoiced' => 'Трябва да се префактурира',
    'view_expense' => 'Преглед на разход # :expense',
    'edit_expense' => 'Редакция на разход',
    'archive_expense' => 'Архивиране на разход',
    'delete_expense' => 'Изтриване на разход',
    'view_expense_num' => 'Разход # :expense',
    'updated_expense' => 'Успешна актуализация на разход',
    'created_expense' => 'Успешно създаден разход',
    'enter_expense' => 'Въведете разход',
    'view' => 'Преглед',
    'restore_expense' => 'Възстановяване на разход',
    'invoice_expense' => 'Префактуриране на разход',
    'expense_error_multiple_clients' => 'Разходът не може да принадлежи на различни клиенти',
    'expense_error_invoiced' => 'Разходът вече е префактуриран',
    'convert_currency' => 'Конвертиране на валутата',
    'num_days' => 'Брой дни',
    'create_payment_term' => 'Създаване на условие за плащане',
    'edit_payment_terms' => 'Редакция на условие за плащане',
    'edit_payment_term' => 'Редакция на условие за плащане',
    'archive_payment_term' => 'Архижиране на условие за плащане',
    'recurring_due_dates' => 'Периодични падежи на фактура',
    'recurring_due_date_help' => '<p>Автоматично задава падежа на фактурата.</p>
        <p>Фактури с месечен или годишен цикъл заложени с падеж на или преди деня на създаване ще бъдат с падеж следващия месец. Фактурите заложени за 29-и или 30-и през месеците, в които няма такава дата, ще бъдат с падеж последния ден на месеца.</p>
        <p>Фактурите със седмичен цикъл заложени с падеж деня, в който са създадени, ще бъдат с първи падеж следващата седмица.</p>
        <p>Пример:</p>
        <ul>
          <li>Днес е 15-ти, падежът е 1-во число на следващия месец. Датата ще бъде първо число на следващия месец.</li>
          <li>Днес е 15-ти, дата е заложена последният ден от месеца. Датата ще бъде последният ден от този месец.
</li>
          <li>Днес е 15-ти, заложена е дата 15-то число на месеца. Първата дата ще бъде 15-ти на <strong>следващия</strong> месец.
</li>
          <li>Днес е петък, заложена е дата "първи петък след". Ефективната дата ще бъде следващият петък, не днес.
</li>
        </ul>',
    'due' => 'Падеж',
    'next_due_on' => 'Следващ падеж: :date',
    'use_client_terms' => 'Използване на клиентските условия',
    'day_of_month' => ':ordinal число на месеца',
    'last_day_of_month' => 'Последен ден на месеца',
    'day_of_week_after' => ':ordinal :day след',
    'sunday' => 'неделя',
    'monday' => 'понеделник',
    'tuesday' => 'вторник',
    'wednesday' => 'сряда',
    'thursday' => 'четвъртък',
    'friday' => 'петък',
    'saturday' => 'събота',
    'header_font_id' => 'Шрифт на заглавие',
    'body_font_id' => 'Шрифт на основен текст',
    'color_font_help' => 'Забележка: Основният цвят и шрифт се използват също и в клиентския портал и персонализираните имейли.',
    'live_preview' => 'Преглед',
    'invalid_mail_config' => 'Грешка при изпращане на имейл. Моля, проверете настройките за имейл.',
    'invoice_message_button' => 'За да видите своята фактура на стойност :amount, кликнете върху бутона.',
    'quote_message_button' => 'За да видите своята оферта на стойност :amount, кликнете върху бутона.',
    'payment_message_button' => 'Благодарим Ви за плащането на :amount',
    'payment_type_direct_debit' => 'Директен дебит',
    'bank_accounts' => 'Кредитни карти и банки',
    'add_bank_account' => 'Добавяне на банкова сметка',
    'setup_account' => 'Настойка на сметка',
    'import_expenses' => 'Импорт на разходи',
    'bank_id' => 'Банка',
    'integration_type' => 'Тип интеграция',
    'updated_bank_account' => 'Успешно актуализирана банкова сметка',
    'edit_bank_account' => 'Редакция на банкова сметка',
    'archive_bank_account' => 'Архивиране на банкова сметка',
    'archived_bank_account' => 'Успешно архивирана банкова сметка',
    'created_bank_account' => 'Успешно създадена банкова сметка',
    'validate_bank_account' => 'Валидиране на банкова сметка',
    'bank_password_help' => 'Забележка: Паролата Ви се изпраща по сигурен канал и никога не се съхранява на нашите сървъри.',
    'bank_password_warning' => 'Внимание: Паролата Ви може да бъде изпратена некриптирана, помислете за активиране на протокола HTTPS.',
    'username' => 'Потребителско име',
    'account_number' => 'Номер на сметка',
    'account_name' => 'Име на сметка',
    'bank_account_error' => 'Грешка при извличането на данните за сметката. Моля, проверете своите данни за вход.',
    'status_approved' => 'Одобрена',
    'quote_settings' => 'Настройки за оферти',
    'auto_convert_quote' => 'Автоматично конвертиране',
    'auto_convert_quote_help' => 'Автоматично конвертиране на оферта във фактура при одобрение от клиента.',
    'validate' => 'Валидиране',
    'info' => 'Инфо',
    'imported_expenses' => 'Успешно създадени :count_vendors доставчик/ци и :count_expenses разход/и',
    'iframe_url_help3' => 'Забележка: Ако планирате да приемате данни за кредитни карти, силно препоръчваме да активирате HTTPS на сайта си.',
    'expense_error_multiple_currencies' => 'Разходите не могат да са в различни валути.',
    'expense_error_mismatch_currencies' => 'Валутата на клиента не съвпада с валутата на разхода.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Хедър / Футър',
    'first_page' => 'Първа страница',
    'all_pages' => 'Всички страници',
    'last_page' => 'Последна страница',
    'all_pages_header' => 'Показване на хедъра на',
    'all_pages_footer' => 'Показване на футъра на',
    'invoice_currency' => 'Валута на фактурата',
    'enable_https' => 'Силно препоръчваме да използвате HTTPS за приемане на данни за кредитни карти онлайн.',
    'quote_issued_to' => 'Оферта издадена на',
    'show_currency_code' => 'Код валута',
    'free_year_message' => 'Вашият профил е ъпгрейднат до план Pro за една година безплатно.',
    'trial_message' => 'Вашият профил ще получи безплатен двуседмичен тестов период за нашия план Pro.',
    'trial_footer' => 'Вашият безплатен тестов период за план Pro включва още :count ни, :link за ъпгрейд.',
    'trial_footer_last_day' => 'Това е последният ден на Вашия безплатен тестов период за план Pro, :link за ъпгрейд.',
    'trial_call_to_action' => 'Стартиране на безплатен пробен период',
    'trial_success' => 'Успешно активиран безплатен двуседмичен тестов период за план Pro',
    'overdue' => 'Просрочие',


    'white_label_text' => 'Купете ЕДНОГОДИШЕН лиценз White label за $:price, за да премахнете брандирането на Invoice Ninja от фактурите и клиентския портал.',
    'user_email_footer' => 'Променете настройките зрез имейл тук: :link',
    'reset_password_footer' => 'Ако не сте заявявали възстановяване на паролата, моля свържете се по имейл с нашата поддръжка: :email',
    'limit_users' => 'Съжаляваме, но това ще надвиши лимита от :limit потребители',
    'more_designs_self_host_header' => 'Вземете още 6 дизайна на фактури замо за $:price',
    'old_browser' => 'Моля, използвайте :link',
    'newer_browser' => 'по-нов браузър',
    'white_label_custom_css' => ':link за $:price за активиране на персонализацията на стиловете и за подпомагане на нашия проект.',
    'bank_accounts_help' => 'Свържете банкова сметка за автоматичен импорт на разходи и създаване на доставчици. Поддържа American Express и :link.',
    'us_banks' => '400+ банки от САЩ',

    'pro_plan_remove_logo' => ':link за премахване на логото на Invoice Ninja чрез активиране на План Pro',
    'pro_plan_remove_logo_link' => 'Кликнете тук',
    'invitation_status_sent' => 'Изпратен',
    'invitation_status_opened' => 'Отворен',
    'invitation_status_viewed' => 'Прегледан',
    'email_error_inactive_client' => 'Не могат да бъдат изпращани имейли към неактивни клиенти',
    'email_error_inactive_contact' => 'Не могат да бъдат изпращани имейли към неактивни контакти',
    'email_error_inactive_invoice' => 'Не могат да бъдат изпращани имейли по неактивни фактури',
    'email_error_inactive_proposal' => 'Не могат да бъдат изпращани имейли по неактивни оферти',
    'email_error_user_unregistered' => 'Моля, регистрирайте профила си, за да изпращате имейли',
    'email_error_user_unconfirmed' => 'Моля, потвърдете профила си, за да изпращате имейли',
    'email_error_invalid_contact_email' => 'Невалиден имейл за контакт',

    'navigation' => 'Навигация',
    'list_invoices' => 'Списък фактури',
    'list_clients' => 'Списък клиенти',
    'list_quotes' => 'Списък количества',
    'list_tasks' => 'Списък задачи',
    'list_expenses' => 'Списък задачи',
    'list_recurring_invoices' => 'Списък периодични фактури',
    'list_payments' => 'Списък плащания',
    'list_credits' => 'Списък кредити',
    'tax_name' => 'Има на такса',
    'report_settings' => 'Настройки за справки',
    'search_hotkey' => 'бърз клавиш /',

    'new_user' => 'Нов потребител',
    'new_product' => 'Нов продукт',
    'new_tax_rate' => 'Нова такса',
    'invoiced_amount' => 'Фактурирана сума',
    'invoice_item_fields' => 'Полета за редове на фактура',
    'custom_invoice_item_fields_help' => 'Добавете поле при създаване на ред от фактура и изведете етикета и стойността в PDF документа.',
    'recurring_invoice_number' => 'Периодичен номер',
    'recurring_invoice_number_prefix_help' => 'Задайте префикс, който да се използва за номерата на периодични фактури.',

    // Client Passwords
    'enable_portal_password' => 'Защита на фактурите с парола',
    'enable_portal_password_help' => 'Дава възможност да заложите парола за всеки контакт. Ако такава е заложена, контактното лице ще трябва да я въведе преди да види фактурите,',
    'send_portal_password' => 'Автоматично генериране',
    'send_portal_password_help' => 'Ако не бъде заложена парола, такава ще се генерира и ще бъде изпратена с първата фактура.',

    'expired' => 'Изтекла',
    'invalid_card_number' => 'Невалиден номер на кредитна карта.',
    'invalid_expiry' => 'Невалидна дата на валидност.',
    'invalid_cvv' => 'CVV не е валиден.',
    'cost' => 'Цена',
    'create_invoice_for_sample' => 'Забележка: Създайте първата си фактура и я вижте тук.',

    // User Permissions
    'owner' => 'Собственик',
    'administrator' => 'Администратор',
    'administrator_help' => 'Даване на права на потребителя да управлява другите потребители, да променя настойки и да редактира всички записи',
    'user_create_all' => 'Създаване на клиенти, фактури и т.н.',
    'user_view_all' => 'Преглед на всички клиенти, фактури и т.н.',
    'user_edit_all' => 'Редакция на всички клиенти, фактури и т.н.',
    'gateway_help_20' => ':link за регистрация в Sage Pay.',
    'gateway_help_21' => ':link за регистрация в Sage Pay.',
    'partial_due' => 'Частично дължима',
    'restore_vendor' => 'Възстановяване на доставчик',
    'restored_vendor' => 'Успешно възстановяване на доставчик',
    'restored_expense' => 'Успешно възстановяване на разход',
    'permissions' => 'Права за достъп',
    'create_all_help' => 'Права за създаване и редакция на записи',
    'view_all_help' => 'Права за виждане на записи, които потребителят не е създал',
    'edit_all_help' => 'Права за редакция на записи, които потребителят не е създал',
    'view_payment' => 'Преглед на плащането',

    'january' => 'Януари',
    'february' => 'Февруари',
    'march' => 'Март',
    'april' => 'Април',
    'may' => 'Май',
    'june' => 'Юни',
    'july' => 'Юли',
    'august' => 'Август',
    'september' => 'Септември',
    'october' => 'Октомври',
    'november' => 'Ноември',
    'december' => 'Декември',

    // Documents
    'documents_header' => 'Документи:',
    'email_documents_header' => 'Документи:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Документи оферта',
    'invoice_documents' => 'окументи фактура',
    'expense_documents' => 'Документи разходи',
    'invoice_embed_documents' => 'Свързани документи',
    'invoice_embed_documents_help' => 'Включване на прикачените изображения във фактурата.',
    'document_email_attachment' => 'Прикачване на Документи',
    'ubl_email_attachment' => 'Прикачване на UBL',
    'download_documents' => 'Документи за изтегляне (:size)',
    'documents_from_expenses' => 'От разходи:',
    'dropzone_default_message' => 'Пуснете тук флайловете или кликнете за качване',
    'dropzone_default_message_disabled' => 'Деактивирано качване на файлове',
    'dropzone_fallback_message' => 'Вашият браузър не поддържа drag\'n\'drop качване на файлове.',
    'dropzone_fallback_text' => 'Моля, използвайте формуляра долу, за да качите файловете по "старомодния начин".',
    'dropzone_file_too_big' => 'Файлът е твърде голям ({{filesize}}MiB). Макс. размер: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Не можете да качвате файлове от този тип.',
    'dropzone_response_error' => 'Сървърът отговаря с код {{statusCode}}.',
    'dropzone_cancel_upload' => 'Отмени качването',
    'dropzone_cancel_upload_confirmation' => 'Сигурни ли сте, че искате да отмените качването?',
    'dropzone_remove_file' => 'Изтрий файл',
    'documents' => 'Документи',
    'document_date' => 'Дата на документа',
    'document_size' => 'Големина',

    'enable_client_portal' => 'Портал на клиента',
    'enable_client_portal_help' => 'Покажи/скрий портала на клиента',
    'enable_client_portal_dashboard' => 'Табло',
    'enable_client_portal_dashboard_help' => 'Показване / скриване на страницата Табло в клиентския портал.',

    // Plans
    'account_management' => 'Управление на акаунтите',
    'plan_status' => 'Статус на плана',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Промяна на плана',
    'pending_change_to' => 'Промяна към',
    'plan_changes_to' => ':plan на :date',
    'plan_term_changes_to' => ':plan (:term) на :date',
    'cancel_plan_change' => 'Отказ от промяна',
    'plan' => 'План',
    'expires' => 'Изтича',
    'renews' => 'Подновяване',
    'plan_expired' => ':plan планът е изтекъл',
    'trial_expired' => 'Тестовият период на план :plan е завършил',
    'never' => 'Никога',
    'plan_free' => 'Безплатен',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Безплатен)',
    'plan_trial' => 'Тестов период',
    'plan_term' => 'Срок',
    'plan_term_monthly' => 'Месечно',
    'plan_term_yearly' => 'Годишно',
    'plan_term_month' => 'Месец',
    'plan_term_year' => 'Година',
    'plan_price_monthly' => '$:price/мес.',
    'plan_price_yearly' => '$:price/година',
    'updated_plan' => 'Актуализирани настройки на плана',
    'plan_paid' => 'Срокът е започнал',
    'plan_started' => 'Планът е стартиран',
    'plan_expires' => 'Планът изтича',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'Включване за една година в план Invoice Ninja Pro.',
    'pro_plan_month_description' => 'Включване за един месец в план Invoice Ninja Pro.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'Включване за една година в план Invoice Ninja Enterprise.',
    'enterprise_plan_month_description' => 'Включване за един месец в план  Invoice Ninja Enterprise.',
    'plan_credit_product' => 'Кредит',
    'plan_credit_description' => 'Кредит или неизползвано време',
    'plan_pending_monthly' => 'Ще премине към месечно на :date',
    'plan_refunded' => 'Издадена е сума за възстановяване.',

    'live_preview' => 'Преглед',
    'page_size' => 'Размер на страницата',
    'live_preview_disabled' => 'Прекледът на документа на живо е изключен заради избрания шрифт',
    'invoice_number_padding' => 'Отстояние',
    'preview' => 'Преглед',
    'list_vendors' => 'Списък доставчици',
    'add_users_not_supported' => 'Преминете към план Enterprise за да добавите още потребители.',
    'enterprise_plan_features' => 'Планът Enterprise посволява множество потребители и прикачени файлове, :link за пълен списък на функциите.',
    'return_to_app' => 'Обратно към приложението',


    // Payment updates
    'refund_payment' => 'Възстановяване на плащане',
    'refund_max' => 'Max:',
    'refund' => 'Възстановяване',
    'are_you_sure_refund' => 'Възстановяване на избраните плащания?',
    'status_pending' => 'Обработка',
    'status_completed' => 'Завършено',
    'status_failed' => 'Отказ',
    'status_partially_refunded' => 'Частично възстановено',
    'status_partially_refunded_amount' => ':amount възстановени',
    'status_refunded' => 'Възстановено',
    'status_voided' => 'Отказано',
    'refunded_payment' => 'Възстановено плащане',
    'activity_39' => ':user е отказал :payment_amount за плащане :payment',
    'activity_40' => ':user е възстановил :adjustment на стойност :payment_amount за плащане :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Неизвестно',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'Поддръжката на ACH трябва да е разрешена в :link.',
    'ach_disabled' => 'Вече е конфигуриран друг портал за директни дебити.',

    'plaid' => 'Платено',
    'client_id' => 'Client Id',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(опция)',
    'plaid_environment_help' => 'При предоставяне на тестов ключ на Stripe ще се използва тестовата развойна среда на Plaid\'s (tartan).',
    'other_providers' => 'Други доставчици',
    'country_not_supported' => 'Тази държава не се поддържа.',
    'invalid_routing_number' => 'Банковият код не е валиден.',
    'invalid_account_number' => 'Номерът на сметката не е валиден.',
    'account_number_mismatch' => 'Номерата на сметките не съвпадат.',
    'missing_account_holder_type' => 'Моля, изберете сметка на физическо лице или фирма.',
    'missing_account_holder_name' => 'Моля, въведете името на титуляра на сметката.',
    'routing_number' => 'Банков код',
    'confirm_account_number' => 'Потвърждение на номера на сметката',
    'individual_account' => 'Сметка на физическо лице',
    'company_account' => 'Сметка на фирма',
    'account_holder_name' => 'Име на титуляра на сметката',
    'add_account' => 'Добавяне на сметка',
    'payment_methods' => 'Методи за плащане',
    'complete_verification' => 'Завършване на верификацията',
    'verification_amount1' => 'Сума 1',
    'verification_amount2' => 'Сума 2',
    'payment_method_verified' => 'Верификацията е завършена успешно',
    'verification_failed' => 'Неуспешна верификация',
    'remove_payment_method' => 'Премахване на метод за плащане',
    'confirm_remove_payment_method' => 'Наистина ли искате да премахнете този метод на плащане?',
    'remove' => 'Премахване',
    'payment_method_removed' => 'Методът на плащане е премахнат.',
    'bank_account_verification_help' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement. Please enter the amounts below.',
    'bank_account_verification_next_steps' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement.
        Once you have the amounts, come back to this payment methods page and click "Complete Verification" next to the account.',
    'unknown_bank' => 'Неизвестна банка',
    'ach_verification_delay_help' => 'Ще можете да използвате сметката след завършване на верификацията. Верификацията обичайно отнема 1-2 работни дни.',
    'add_credit_card' => 'Добавяне на кредитна карта',
    'payment_method_added' => 'Добавен метод за плащане.',
    'use_for_auto_bill' => 'Използване за Autobill',
    'used_for_auto_bill' => 'Метод за плащане Autobill',
    'payment_method_set_as_default' => 'Set Autobill payment method.',
    'activity_41' => 'Отказани :payment_amount по плащане (:payment)',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Трябва :link.',
    'stripe_webhook_help_link_text' => 'да добавите този URL като endpoint в Stripe',
    'gocardless_webhook_help_link_text' => 'да добавите този URL като endpoint в GoCardless',
    'payment_method_error' => 'Грешка при добавяне на метода за плащане. Моля, опитайте отново по-късно.',
    'notification_invoice_payment_failed_subject' => 'Отказано плащане по фактура :invoice',
    'notification_invoice_payment_failed' => 'Плащане направено от клиент :client към фактура :invoice е отказано. Плащането е маркирано като отказано и сумата :amount е добавена към баланса на клиента.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Вашата банкова сметка в :bank',
    'add_payment_method' => 'Добавяне на метод за плащане',
    'account_holder_type' => 'Тип титуляр на сметката',
    'ach_authorization' => 'I authorize :company to use my bank account for future payments and, if necessary, electronically credit my account to correct erroneous debits. I understand that I may cancel this authorization at any time by removing the payment method or by contacting :email.',
    'ach_authorization_required' => 'You must consent to ACH transactions.',
    'off' => 'Изкл.',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Винаги',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Manage Auto-bill',
    'enabled' => 'Активно',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'The PayPal gateway is processing PayPal payments',
    'braintree_paypal_help' => 'You must also :link.',
    'braintree_paypal_help_link_text' => 'link PayPal to your BrainTree account',
    'token_billing_braintree_paypal' => 'Съхраняване на детайлите за плащане',
    'add_paypal_account' => 'Добавяне на PayPal сметка',


    'no_payment_method_specified' => 'Не е избран метод за плащане',
    'chart_type' => 'Chart Type',
    'format' => 'Формат',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed to parse OFX file',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up with WePay',
    'use_another_provider' => 'Използване на друг доставчик',
    'company_name' => 'Име на фирма',
    'wepay_company_name_help' => 'Ще бъде изведено на извлечението по кредитната карта на клиента.',
    'wepay_description_help' => 'Целта на този акаунт.',
    'wepay_tos_agree' => 'Съгласявам се с :link.',
    'wepay_tos_link_text' => 'WePay Terms of Service',
    'resend_confirmation_email' => 'Повторно изпращане на имейл за потвърждение',
    'manage_account' => 'Управление на профил',
    'action_required' => 'Action Required',
    'finish_setup' => 'Завършване на настройките',
    'created_wepay_confirmation_required' => 'Моля, проверете имейла си и потвърдете адреса си в WePay.',
    'switch_to_wepay' => 'Прехвърляне към WePay',
    'switch' => 'Прехвърляне',
    'restore_account_gateway' => 'Възстановяване на портал',
    'restored_account_gateway' => 'Успешно възстановен портал',
    'united_states' => 'United States',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Приемане на дебитни карти',
    'debit_cards' => 'Дебитна карта',

    'warn_start_date_changed' => 'Следващата фактура ще бъде изпратена на новата стартова дата.',
    'warn_start_date_changed_not_sent' => 'Следващата фактура ще бъде създадена на новата стартова дата.',
    'original_start_date' => 'Оригинална стартова дата',
    'new_start_date' => 'Нова стартова дата',
    'security' => 'Сигурност',
    'see_whats_new' => 'Вижте новостите във версия v:version',
    'wait_for_upload' => 'Моля, изчакайте качването на документа.',
    'upgrade_for_permissions' => 'Преминете към нашия план Enterprise за да активирате потребителските права.',
    'enable_second_tax_rate' => 'Активирайте като определите <b>втора данъчна ставка</b>',
    'payment_file' => 'Файл за плащане',
    'expense_file' => 'Файл с разходи',
    'product_file' => 'Файл с продукти',
    'import_products' => 'Импорт на продукти',
    'products_will_create' => 'продукт/и ще бъдат създадени',
    'product_key' => 'Продукт',
    'created_products' => 'Успешно създадени/актуализирани :count продукт(и)',
    'export_help' => 'Използвайте JSON ако планирате да импортирате данни в Invoice Ninja.<br/>Файлът съдържа клиенти, продукти, фактури, оферти и плащания.',
    'selfhost_export_help' => '<br/>Препоръчваме да използвате mysqldump за създаване на пълен архив.',
    'JSON_file' => 'JSON файл',

    'view_dashboard' => 'Вижте таблото',
    'client_session_expired' => 'Сесията е изтекла',
    'client_session_expired_message' => 'Вашата сесия е изтекла. Моля, отворете отново линка от имейла си.',

    'auto_bill_notification' => 'Тази фактура ще бъде начислена автоматично за плащане към Вашата :payment_method на :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'банкова сметка',
    'auto_bill_payment_method_credit_card' => 'кредитна карта',
    'auto_bill_payment_method_paypal' => 'PayPal сметка',
    'auto_bill_notification_placeholder' => 'Тази фактура ще бъде начислена автоматично за плащане от Вашата кредитна карта на датата на падежа.',
    'payment_settings' => 'Настройки за плащания',

    'on_send_date' => 'На датата на изпращане',
    'on_due_date' => 'На датата на падежа',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on the due date.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Банкова сметка',
    'payment_processed_through_wepay' => 'ACH плащанията се обработват през WePay.',
    'wepay_payment_tos_agree' => 'Съгласен съм с :terms и :privacy_policy на WePay.',
    'privacy_policy' => 'Политика за защита на личните данни',
    'wepay_payment_tos_agree_required' => 'Трябва да се съгласите с Условията за ползване и Политиката за защита на личните данни на WePay.',
    'ach_email_prompt' => 'Моля, въведете своя имейл адрес:',
    'verification_pending' => 'Очаквана верификация',

    'update_font_cache' => 'Моля, опреснете страницата, за да актуализирате шрифтовете.',
    'more_options' => 'Още',
    'credit_card' => 'Кредитна карта',
    'bank_transfer' => 'Банков трансфер',
    'no_transaction_reference' => 'Не сме получили референция на транзакцията от платежния портал.',
    'use_bank_on_file' => 'Използвайте наличните банкови данни',
    'auto_bill_email_message' => 'Фактурата ще бъде автоматично добавена за плащане чрез съхранения в профила метод за плащане на датата на падежа.',
    'bitcoin' => 'Биткойн',
    'gocardless' => 'GoCardless',
    'added_on' => 'Добавена :date',
    'failed_remove_payment_method' => 'Грешка при премахване на метода на плащане',
    'gateway_exists' => 'Този портал вече съществува',
    'manual_entry' => 'Ръчно въвеждане',
    'start_of_week' => 'Първи ден от седмицата',

    // Frequencies
    'freq_inactive' => 'Неактивно',
    'freq_daily' => 'Ежедневно',
    'freq_weekly' => 'Седмично',
    'freq_biweekly' => 'На две седмици',
    'freq_two_weeks' => 'Две седмици',
    'freq_four_weeks' => 'Четири седмици',
    'freq_monthly' => 'Месечно',
    'freq_three_months' => 'Три месеца',
    'freq_four_months' => 'Четири месеца',
    'freq_six_months' => 'Шест месеца',
    'freq_annually' => 'Годишно',
    'freq_two_years' => 'На две години',

    // Payment types
    'payment_type_Apply Credit' => 'Кредит',
    'payment_type_Bank Transfer' => 'Банков трансфер',
    'payment_type_Cash' => 'В брой',
    'payment_type_Debit' => 'Дебит',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Друга кредитна карта',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Счетоводство и правни услуги',
    'industry_Advertising' => 'Реклама',
    'industry_Aerospace' => 'Авиация',
    'industry_Agriculture' => 'Селско стопанство',
    'industry_Automotive' => 'Автомобилна индустрия',
    'industry_Banking & Finance' => 'Банки и финанси',
    'industry_Biotechnology' => 'Биотехнологии',
    'industry_Broadcasting' => 'Телевизия и радио',
    'industry_Business Services' => 'Бизнес услуги',
    'industry_Commodities & Chemicals' => 'Суровини и химикали',
    'industry_Communications' => 'Комуникации',
    'industry_Computers & Hightech' => 'Информационни технологии',
    'industry_Defense' => 'Отбрана',
    'industry_Energy' => 'Енергетика',
    'industry_Entertainment' => 'Развлекателна индустрия',
    'industry_Government' => 'Правителствен сектор',
    'industry_Healthcare & Life Sciences' => 'Здравеопазване',
    'industry_Insurance' => 'Застраховане',
    'industry_Manufacturing' => 'Производство',
    'industry_Marketing' => 'Маркетинг',
    'industry_Media' => 'Медии',
    'industry_Nonprofit & Higher Ed' => 'НПО',
    'industry_Pharmaceuticals' => 'Фармацевтика',
    'industry_Professional Services & Consulting' => 'Професионални услуги и консултации',
    'industry_Real Estate' => 'Недвижими имоти',
    'industry_Restaurant & Catering' => 'Ресторантьорство',
    'industry_Retail & Wholesale' => 'Продажби на дребно и едро',
    'industry_Sports' => 'Спорт',
    'industry_Transportation' => 'Транспорт',
    'industry_Travel & Luxury' => 'Пътувания и луксозни стоки',
    'industry_Other' => 'Друго',
    'industry_Photography' => 'Фотография',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'България',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Croatian',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Greek',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finnish',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Български',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Счетоводство и правни услуги',
    'industry_Advertising' => 'Реклама',
    'industry_Aerospace' => 'Авиация',
    'industry_Agriculture' => 'Селско стопанство',
    'industry_Automotive' => 'Автомобилна индустрия',
    'industry_Banking & Finance' => 'Банки и финанси',
    'industry_Biotechnology' => 'Биотехнологии',
    'industry_Broadcasting' => 'Телевизия и радио',
    'industry_Business Services' => 'Бизнес услуги',
    'industry_Commodities & Chemicals' => 'Суровини и химикали',
    'industry_Communications' => 'Комуникации',
    'industry_Computers & Hightech' => 'Информационни технологии',
    'industry_Defense' => 'Отбрана',
    'industry_Energy' => 'Енергетика',
    'industry_Entertainment' => 'Развлекателна индустрия',
    'industry_Government' => 'Правителствен сектор',
    'industry_Healthcare & Life Sciences' => 'Здравеопазване',
    'industry_Insurance' => 'Застраховане',
    'industry_Manufacturing' => 'Производство',
    'industry_Marketing' => 'Маркетинг',
    'industry_Media' => 'Медии',
    'industry_Nonprofit & Higher Ed' => 'НПО',
    'industry_Pharmaceuticals' => 'Фармацевтика',
    'industry_Professional Services & Consulting' => 'Професионални услуги и консултации',
    'industry_Real Estate' => 'Недвижими имоти',
    'industry_Retail & Wholesale' => 'Продажби на дребно и едро',
    'industry_Sports' => 'Спорт',
    'industry_Transportation' => 'Транспорт',
    'industry_Travel & Luxury' => 'Пътувания и луксозни стоки',
    'industry_Other' => 'Друго',
    'industry_Photography' => 'Фотография',

    'view_client_portal' => 'Към клиентския портал',
    'view_portal' => 'Преглед на портала',
    'vendor_contacts' => 'Контакти доставчици',
    'all' => 'Всички',
    'selected' => 'Избрани',
    'category' => 'Категория',
    'categories' => 'Категории',
    'new_expense_category' => 'Нова категория разходи',
    'edit_category' => 'Редакция на категория',
    'archive_expense_category' => 'Архивиране на категория',
    'expense_categories' => 'Категории разходи',
    'list_expense_categories' => 'Списък с категории разходи',
    'updated_expense_category' => 'Успешна актуализация на категория разходи',
    'created_expense_category' => 'Успешно създаване на категория разходи',
    'archived_expense_category' => 'Успешно архивиране на категория разходи',
    'archived_expense_categories' => 'Успешно архивирани :count категории разходи',
    'restore_expense_category' => 'Възстановяване на категория разходи',
    'restored_expense_category' => 'Успешно възстановяване на категория разходи',
    'apply_taxes' => 'Прилагане на данъци',
    'min_to_max_users' => ':min до :max потребители',
    'max_users_reached' => 'Достигнат е максималният брой потребители.',
    'buy_now_buttons' => 'Бутони "Купи сега"',
    'landing_page' => 'Начална страница',
    'payment_type' => 'Тип плащане',
    'form' => 'Формуляр',
    'link' => 'Линк',
    'fields' => 'Полета',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Забележка: Клиентът и фактурата се създават дори и транзакцията да не е завършена.',
    'buy_now_buttons_disabled' => 'Тази функция изисква да е създаден продукт и да е конфигуриран портал за плащане.',
    'enable_buy_now_buttons_help' => 'Активиране на поддръжка на бутон "Купи сега"',
    'changes_take_effect_immediately' => 'Забележка: Промените влизат в сила веднага',
    'wepay_account_description' => 'Портал за плащане за Invoice Ninja',
    'payment_error_code' => 'Грешка при обработка на плащането [:code]. Моля, опитайте отново по-късно.',
    'standard_fees_apply' => 'Такса: 2.9%/1.2% [кредитна карта/банков трансфер] + $0.30 на успешно плащане.',
    'limit_import_rows' => 'Данните трябва да се импортират по :count или по-малко реда',
    'error_title' => 'Настъпила е грешка',
    'error_contact_text' => 'Ако имате нужда от помощ, свържете се с нас по имейл на :mailaddress',
    'no_undo' => 'Внимание: това не може да бъде възстановено обратно.',
    'no_contact_selected' => 'Моля, изберете контакт',
    'no_client_selected' => 'Моля, изберете клиент',

    'gateway_config_error' => 'Може да е от полза да заложите нови пароли или да генерирате нови API ключове.',
    'payment_type_on_file' => ':type в системата',
    'invoice_for_client' => 'Фактура :invoice за :client',
    'intent_not_found' => 'Съжалявам, но не съм сигурен какво питате.',
    'intent_not_supported' => 'Съжалявам, но не мога да направя това.',
    'client_not_found' => 'Не успях да намеря клиента',
    'not_allowed' => 'За съжаление нямате необходимите права',
    'bot_emailed_invoice' => 'Вашата фактура е изпратена.',
    'bot_emailed_notify_viewed' => 'Ще се свържа с Вас по имейл, когато е прегледано.',
    'bot_emailed_notify_paid' => 'Ще се свържа с Вас по имейл, когато е платено.',
    'add_product_to_invoice' => 'Добавяне на 1 :product',
    'not_authorized' => 'Нямате оторизация',
    'bot_get_email' => 'Здравейтеi! (wave)<br/>Благодарим, че тествахте Invoice Ninja Bot.<br/>Трябва да създадете безплатен акаунт, за да използвате този bot.<br/>За начало ми изпратете имейл адреса на своя акаунт.',
    'bot_get_code' => 'Благодаря! Изпратихе Ви имейл с Вашия код за сигурност.',
    'bot_welcome' => 'Готово! Профилът Ви е потвърден.',
    'email_not_found' => 'Не успях да открия профил на :email',
    'invalid_code' => 'Кодът е некоректен',
    'security_code_email_subject' => 'Код за сигурност за Invoice Ninja Bot',
    'security_code_email_line1' => 'Това е Вашият код за сигурност за Invoice Ninja Bot.',
    'security_code_email_line2' => 'Забележка: Той ще изтече след 10 минути.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'Списък продукти',

    'include_item_taxes_inline' => 'Включване на <b>данъка по редове в стойността на реда</b>',
    'created_quotes' => 'Успешно създадени :count оферта(и)',
    'limited_gateways' => 'Забележка: Поддържаме по един портал за кредитни карти на компания.',

    'warning' => 'Внимание',
    'self-update' => 'Актуализация',
    'update_invoiceninja_title' => 'Актуализиране на Invoice Ninja',
    'update_invoiceninja_warning' => 'Преди да стартирате актуализация на Invoice Ninja направете архив на своята база данни и фалове!',
    'update_invoiceninja_available' => 'Налична е нова версия на Invoice Ninja.',
    'update_invoiceninja_unavailable' => 'Няма по-нова версия на Invoice Ninja.',
    'update_invoiceninja_instructions' => 'Моля, инсталирайте новата версия <strong>:version</strong> като използвате бутона <em>Актуализирай сега</em>. След това ще бъдете прехвърлени към таблото.',
    'update_invoiceninja_update_start' => 'Актуализирай сега',
    'update_invoiceninja_download_start' => 'Изтегляне на :version',
    'create_new' => 'Нов',

    'toggle_navigation' => 'Превключване на навигацията',
    'toggle_history' => 'Превключване на историята',
    'unassigned' => 'Неприсвоена',
    'task' => 'Задача',
    'contact_name' => 'Контакт - име',
    'city_state_postal' => 'Град / Щат / Пощ. код',
    'custom_field' => 'Персонализирано поле',
    'account_fields' => 'Фирмени полета',
    'facebook_and_twitter' => 'Facebook и Twitter',
    'facebook_and_twitter_help' => 'Следвайте ни, за да подпомогнете проекта',
    'reseller_text' => 'Забележка: Лицензът White label е предназначен за персонална употреба. Моля, свържете се с нас по имейл на :email, ако желаете да препродавате приложението.',
    'unnamed_client' => 'Клиент без име',

    'day' => 'Ден',
    'week' => 'Седмица',
    'month' => 'Месец',
    'inactive_logout' => 'Излезли сте от профила си поради неактивност',
    'reports' => 'Справки',
    'total_profit' => 'Обща печалба',
    'total_expenses' => 'Общо разходи',
    'quote_to' => 'Оферта за',

    // Limits
    'limit' => 'Лимит',
    'min_limit' => 'Мин.: :min',
    'max_limit' => 'Макс.: :max',
    'no_limit' => 'Без лимит',
    'set_limits' => 'Заложете лимити за :gateway_type',
    'enable_min' => 'Активиране на min',
    'enable_max' => 'Активиране на max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Фактурата не съответства на лимитите за този тип плащане.',

    'date_range' => 'Период',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Актуализация',
    'invoice_fields_help' => 'Издърпайте и влачете полетата, за да промените техния ред и местоположение',
    'new_category' => 'Нова категория',
    'restore_product' => 'Възстановяване на продукт',
    'blank' => 'Празно',
    'invoice_save_error' => 'Грешка при съхранение на фактурата',
    'enable_recurring' => 'Активиране на периодичност',
    'disable_recurring' => 'Деактивиране на периодичност',
    'text' => 'Текст',
    'expense_will_create' => 'разход ще бъде създаден',
    'expenses_will_create' => 'азходи ще бъдат създадени',
    'created_expenses' => 'Успешно създадени :count разход(и)',

    'translate_app' => 'Помогнете да подобрим превода чрез :link',
    'expense_category' => 'Категория разход',

    'go_ninja_pro' => 'Вземете Ninja Pro!',
    'go_enterprise' => 'Вземете план Enterprise!',
    'upgrade_for_features' => 'Ъпгрейдвайте плана си за повече функции',
    'pay_annually_discount' => 'Плащайте годишно за 10 месеца + 2 безплатно!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Персонализирайте всеки аспект на своите фактури!',
    'enterprise_upgrade_feature1' => 'Задайте права за множество потребители',
    'enterprise_upgrade_feature2' => 'Прикачвайте файлове на 3-ти страни към фактурите и разходите',
    'much_more' => 'Още повече!',
    'all_pro_fetaures' => 'Плюс всички функционалности на план Pro!',

    'currency_symbol' => 'Символ',
    'currency_code' => 'Код',

    'buy_license' => 'Купете лиценз',
    'apply_license' => 'Въведете лиценз',
    'submit' => 'Изпращане',
    'white_label_license_key' => 'Лицензен ключ',
    'invalid_white_label_license' => 'Ключът за лиценз White label не е валиден',
    'created_by' => 'Създаден от :name',
    'modules' => 'Модули',
    'financial_year_start' => 'Първи месец на годината',
    'authentication' => 'Автентикация',
    'checkbox' => 'Чек-бокс',
    'invoice_signature' => 'Подпис',
    'show_accept_invoice_terms' => 'Чек-бокс за условия на фактура',
    'show_accept_invoice_terms_help' => 'Изискване клиенът да потвърди, че приема условията на фактурата',
    'show_accept_quote_terms' => 'Чек-бокс за условия на офертата',
    'show_accept_quote_terms_help' => 'Изискване клиенът да потвърди, че приема условията на офертата',
    'require_invoice_signature' => 'Подпис на фактурата',
    'require_invoice_signature_help' => 'Изискване клиентът да подпише',
    'require_quote_signature' => 'Подпис на офертата',
    'require_quote_signature_help' => 'Изискване клиентът да подпише',
    'i_agree' => 'Съгласен съм с условията',
    'sign_here' => 'Моля, подпишете тук:',
    'authorization' => 'Оторизация',
    'signed' => 'Подписано',

    // BlueVine
    'bluevine_promo' => 'Гъвкави бизнес линии за факторинг по кредити и фактури чрез BlueVine.',
    'bluevine_modal_label' => 'Регистрация в BlueVine',
    'bluevine_modal_text' => '<h3>Бързо финансиране за Вашия бизнес. Без излишна бумащина.</h3>
<ul><li>Гъвкави бизнес линии за факторинг по кредити и фактури.</li></ul>',
    'bluevine_create_account' => 'Създаване на профил',
    'quote_types' => 'Искане на оферта за',
    'invoice_factoring' => 'Факторинг на фактури',
    'line_of_credit' => 'Кредитна линия',
    'fico_score' => 'Вашият FICO резултат',
    'business_inception' => 'Дата на започване на дейността',
    'average_bank_balance' => 'Среден баланс по банкови сметки',
    'annual_revenue' => 'Годишни приходи',
    'desired_credit_limit_factoring' => 'Желан лимит за факторинг на фактури',
    'desired_credit_limit_loc' => 'Желан лимит на кредитна линия',
    'desired_credit_limit' => 'Желан кредитен лимит',
    'bluevine_credit_line_type_required' => 'Трябва да изберете поне едно',
    'bluevine_field_required' => 'Това поле е задължително',
    'bluevine_unexpected_error' => 'Настъпила е неочаквана грешка.',
    'bluevine_no_conditional_offer' => 'Нужна е повече информация преди да получите оферта. Кликнете върху Продължи.',
    'bluevine_invoice_factoring' => 'Факторинг на фактури',
    'bluevine_conditional_offer' => 'Оферта под условие',
    'bluevine_credit_line_amount' => 'Кредитна линия',
    'bluevine_advance_rate' => 'Авансова ставка',
    'bluevine_weekly_discount_rate' => 'Седмична ставка на отстъпка',
    'bluevine_minimum_fee_rate' => 'Минимална такса',
    'bluevine_line_of_credit' => 'Кредитна линия',
    'bluevine_interest_rate' => 'Лихвен процент',
    'bluevine_weekly_draw_rate' => 'Седмичен Draw Rate',
    'bluevine_continue' => 'Продължи към BlueVine',
    'bluevine_completed' => 'Завършена регистрация в BlueVine',

    'vendor_name' => 'Доставчик',
    'entity_state' => 'Щат',
    'client_created_at' => 'Дата на издаване',
    'postmark_error' => 'Проблем при изпращане на имейла чрез Postmark: :link',
    'project' => 'Проект',
    'projects' => 'Проекти',
    'new_project' => 'Нов проект',
    'edit_project' => 'Редакция на проект',
    'archive_project' => 'Архивиране на проект',
    'list_projects' => 'Списък проекти',
    'updated_project' => 'Успешна актуализация на проект',
    'created_project' => 'Успешно създаден проект',
    'archived_project' => 'Успешно архивиран проект',
    'archived_projects' => 'Успешно архивирани :count проекта',
    'restore_project' => 'Възстановяване на проект',
    'restored_project' => 'Успешно възстановен проект',
    'delete_project' => 'Изтриване на проект',
    'deleted_project' => 'Успешно изтрит проект',
    'deleted_projects' => 'Успешно изтрити :count проекта',
    'delete_expense_category' => 'Изтриване на категория',
    'deleted_expense_category' => 'Успешно изтрита категория',
    'delete_product' => 'Изтриване на продукт',
    'deleted_product' => 'Успешно изтрит продукт',
    'deleted_products' => 'Успешно изтрити :count продукта',
    'restored_product' => 'Успешно възстановен продукт',
    'update_credit' => 'Актуализация на кредит',
    'updated_credit' => 'Успешна актуализация на кредит',
    'edit_credit' => 'Редакция на кредит',
    'realtime_preview' => 'Превю в реално време',
    'realtime_preview_help' => 'Опреснява в реално време PDF превюто в екрана за редакция на фактура.<br/>Изключете това за да избегнете забавяне, когато редактирате фактури.',
    'live_preview_help' => 'Показване на PDF превю на страницата на фактурата',
    'force_pdfjs_help' => 'Заменете вградения PDF viewer в :chrome_link и :firefox_link.<br/>Активирайте това, ако браузърът Ви автоматично изтегля PDF документа.',
    'force_pdfjs' => 'Предотвратяване на изтеглянето',
    'redirect_url' => 'URL за пренасочване',
    'redirect_url_help' => 'Опционно въведете URL за пренасочване след въвеждане на плащане.',
    'save_draft' => 'Запис на чернова',
    'refunded_credit_payment' => 'Възстановено кредитно плащане',
    'keyboard_shortcuts' => 'Клавишни комбинации',
    'toggle_menu' => 'Превключване на менюто',
    'new_...' => 'Нов ...',
    'list_...' => 'Списък ...',
    'created_at' => 'Дата на създаване',
    'contact_us' => 'Свържете се с нас',
    'user_guide' => 'Ръководство за потребителя',
    'promo_message' => 'Ъпгрейдвайте плана си преди :expires и всемете ОТСТЪПКА :amount от първата година на своя Pro или Enterprise план.',
    'discount_message' => 'Отстъпката от :amount изтича на :expires',
    'mark_paid' => 'Маркирай платено',
    'marked_sent_invoice' => 'Маркираната фактура е изпратена успешно',
    'marked_sent_invoices' => 'Маркираните фактури са изпратени успешно',
    'invoice_name' => 'Фактура',
    'product_will_create' => 'продукт ще бъде създаден',
    'contact_us_response' => 'Благодарим Ви за съобщението! Ще опитаме да Ви отговорим при първа възможност.',
    'last_7_days' => 'Последни 7 дни',
    'last_30_days' => 'Последни 30 дни',
    'this_month' => 'Този месец',
    'last_month' => 'Предишния месец',
    'current_quarter' => 'Настоящо тримесечие',
    'last_quarter' => 'Предишно тримесечие',
    'last_year' => 'Предишна година',
    'custom_range' => 'Друг период',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Require',
    'license_expiring' => 'Забележка: Вашият лиценз ще изтече след :count дни, :link за подновяване.',
    'security_confirmation' => 'Вашият имейл адрес е потвърден.',
    'white_label_expired' => 'Вашият лиценз White label е изтекъл. Моля, подновете го за да подпомогнете нашия проект.',
    'renew_license' => 'Подновяване на лиценз',
    'iphone_app_message' => 'Изтеглете нашето :link',
    'iphone_app' => 'Приложение за iPhone',
    'android_app' => 'Приложение за Android',
    'logged_in' => 'Логнат',
    'switch_to_primary' => 'Превключете към основната си фирма (:name), за да управлявате плана си.',
    'inclusive' => 'Включени',
    'exclusive' => 'Изключени',
    'postal_city_state' => 'Пощ. код / Щат / Град',
    'phantomjs_help' => 'В определени случаи приложението използва :link_phantom за генериране на PDF. Инсталирайте :link_docs за локално генериране.',
    'phantomjs_local' => 'Изполване на локална PhantomJS',
    'client_number' => 'Клиентски номер',
    'client_number_help' => 'Въведете префикс или използвайте персонален шаблон за динамично генериране на клиентски номер.',
    'next_client_number' => 'Следващият клиентски номер е :number.',
    'generated_numbers' => 'Генерирани номера',
    'notes_reminder1' => 'Първо напомняне',
    'notes_reminder2' => 'Второ напомняне',
    'notes_reminder3' => 'Трето напомняне',
    'notes_reminder4' => 'Напомняне',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Данъчна оферта',
    'tax_invoice' => 'Данъчна фактура',
    'emailed_invoices' => 'Успешно изпратени фактури',
    'emailed_quotes' => 'Успешно изпратени оферти',
    'website_url' => 'URL на сайт',
    'domain' => 'Домейн',
    'domain_help' => 'Използва се в клиентския портал и при изпращане на имейли.',
    'domain_help_website' => 'Използва се при изпращане на имейли.',
    'import_invoices' => 'Импорт на фактури',
    'new_report' => 'Нова справка',
    'edit_report' => 'Редакция на справка',
    'columns' => 'Колони',
    'filters' => 'Филтри',
    'sort_by' => 'Сортиране по',
    'draft' => 'Чернова',
    'unpaid' => 'Неплатена',
    'aging' => 'По дата на издаване',
    'age' => 'Издадена преди',
    'days' => 'Дни',
    'age_group_0' => '0 - 30 дни',
    'age_group_30' => '30 - 60 дни',
    'age_group_60' => '60 - 90 дни',
    'age_group_90' => '90 - 120 дни',
    'age_group_120' => '120+ дни',
    'invoice_details' => 'Детайли на фактурата',
    'qty' => 'Количество',
    'profit_and_loss' => 'Печалба и загуба',
    'revenue' => 'Приход',
    'profit' => 'Печалба',
    'group_when_sorted' => 'Групиране при сортиране',
    'group_dates_by' => 'Групиране на датите по',
    'year' => 'Година',
    'view_statement' => 'Вижте извлечение',
    'statement' => 'Извлечение',
    'statement_date' => 'Дата на извлечение',
    'mark_active' => 'Маркирай в архив',
    'send_automatically' => 'Автоматично изпращане',
    'initial_email' => 'Първоначален имейл',
    'invoice_not_emailed' => 'Тази фактура не е изпращана по имейл.',
    'quote_not_emailed' => 'Тази оферта не е изпращана по имейл.',
    'sent_by' => 'Изпратена от :user',
    'recipients' => 'Получатели',
    'save_as_default' => 'Запази като чернова',
    'start_of_week_help' => 'Използва се от селектори на <b>дата</b>',
    'financial_year_start_help' => 'Използва се от селектори на <b>периоди</b>',
    'reports_help' => 'Shift + Click за сортиране по множество колони, Ctrl + Click за изчистване на групирането.',
    'this_year' => 'Тази година',

    // Updated login screen
    'ninja_tagline' => 'Create. Send. Get Paid.',
    'login_or_existing' => 'Или влезте със свързан профил.',
    'sign_up_now' => 'Регистрирайте се сега',
    'not_a_member_yet' => 'Все още нямате профил?',
    'login_create_an_account' => 'Създайте профил!',

    // New Client Portal styling
    'invoice_from' => 'Фактури от:',
    'email_alias_message' => 'Изискваме за всяка фирма да има уникален имей адрес.<br/>Пробвайте да използвате псевдоним, напр. email+label@example.com',
    'full_name' => 'Пълно име',
    'month_year' => 'МЕСЕЦ/ГОДИНА',
    'valid_thru' => 'Валидна\nдо',

    'product_fields' => 'Продуктови полета',
    'custom_product_fields_help' => 'Добавете поле при създаване на продукт или фактура и изведете етикета и съдържанието му в PDF документа.',
    'freq_two_months' => 'Два месеца',
    'freq_yearly' => 'Годишно',
    'profile' => 'Профил',
    'payment_type_help' => 'Задава <b>тип за ръчно плащане</b> по подразбиране.',
    'industry_Construction' => 'Строителство',
    'your_statement' => 'Вашето извлечение',
    'statement_issued_to' => 'Извлечение издадено на',
    'statement_to' => 'Извлечение на',
    'customize_options' => 'Персонализиране на настройки',
    'created_payment_term' => 'Успешно създадено условие на плащане',
    'updated_payment_term' => 'Успешно актуализирано условие на плащане',
    'archived_payment_term' => 'Успешно архивирано условие на плащане',
    'resend_invite' => 'Повторно изпращане на покана',
    'credit_created_by' => 'Кредит създаден по плащане :transaction_reference',
    'created_payment_and_credit' => 'Успешно създадено плащане и кредит',
    'created_payment_and_credit_emailed_client' => 'Успешно създадено плащане и кредит, и изпращане на имейл на клиента',
    'create_project' => 'Създаване на проект',
    'create_vendor' => 'Създаване на доставчик',
    'create_expense_category' => 'Създаване на категория',
    'pro_plan_reports' => ':link за активиране на справки с преминаване към план Pro',
    'mark_ready' => 'Маркирай като готово',

    'limits' => 'Лимити',
    'fees' => 'Такси',
    'fee' => 'Такса',
    'set_limits_fees' => 'Заложете лимити / такси за :gateway_type',
    'fees_tax_help' => 'Активирайте данък по редове,за да заложите данъчни ставки за такси.',
    'fees_sample' => 'Таксата за фактура на стойност :amount ще бъде :total.',
    'discount_sample' => 'Отстъпката за фактура на стойност :amount ще бъде :total.',
    'no_fees' => 'Без такси',
    'gateway_fees_disclaimer' => 'Внимание: Не всички щати / портали за плащане разрешават добавянето на такси. Моля, запознайте се с местното законодателство / условия на услугата.',
    'percent' => 'Процент',
    'location' => 'Местоположение',
    'line_item' => 'Ред',
    'surcharge' => 'Доплащане',
    'location_first_surcharge' => 'Активирано - Първо доплащане',
    'location_second_surcharge' => 'Активирано - Второ доплащане',
    'location_line_item' => 'Активирано - Ред',
    'online_payment_surcharge' => 'Доплащане за онлайн плащане',
    'gateway_fees' => 'Такси на портала',
    'fees_disabled' => 'Таксите са деактивирани',
    'gateway_fees_help' => 'Автоматично добавяне на доплащане / отстъпка за онлайн плащане.',
    'gateway' => 'Портал',
    'gateway_fee_change_warning' => 'Ако има неплатени фактури с такси, те трябва да бъдат актуализирани ръчно.',
    'fees_surcharge_help' => 'Персонализиране на доплащане :link.',
    'label_and_taxes' => 'етикет и данъци',
    'billable' => 'За плащане',
    'logo_warning_too_large' => 'Файлът с изображението е твърде голям.',
    'logo_warning_fileinfo' => 'Внимание: За поддръжка на gif файлове разширението fileinfo на PHP трябва да бъде активно.',
    'logo_warning_invalid' => 'Проблем с файла на изображението. Моля, пробвайте друг формат.',

    'error_refresh_page' => 'Настъпила е грешка. Моля, заредете отново страницата и опитайте пак.',
    'data' => 'Данни',
    'imported_settings' => 'Успешно импортирани настойки',
    'reset_counter' => 'Нулиране на брояч',
    'next_reset' => 'Следващо нулиране',
    'reset_counter_help' => 'Автоматично нулиране на броячите за фактури и оферти',
    'auto_bill_failed' => 'Грешка при автоматичното плащане за фактура :invoice_number',
    'online_payment_discount' => 'Отстъпка за онлайн плащане',
    'created_new_company' => 'Успешно създадена нова компания',
    'fees_disabled_for_gateway' => 'Таксите са деактивирани за този портал.',
    'logout_and_delete' => 'Изход / Изтриване на профил',
    'tax_rate_type_help' => 'Включените данъчни ставки променят стойността на реда, когато бъдат избрани.<br/>Само изключените данъчни ставки могат да бъдат използвани по подразбиране.',
    'invoice_footer_help' => 'Използвайте $pageNumber и $pageCount за извеждане на информация за страницата.',
    'credit_note' => 'Кредитно известие',
    'credit_issued_to' => 'Кредит издаден на',
    'credit_to' => 'Кредит за',
    'your_credit' => 'Ваш кредит',
    'credit_number' => 'Кредит номер',
    'create_credit_note' => 'Създаване на кредитно известие',
    'menu' => 'Меню',
    'error_incorrect_gateway_ids' => 'Грешка: Таблицата с портали за плащане има невалидни id стойности.',
    'purge_data' => 'Изчистване на данни',
    'delete_data' => 'Изтриване на данни',
    'purge_data_help' => 'Перманентно изтриване на всички данни, но запазване на профила и настройките',
    'cancel_account_help' => 'Перманентно изтриване на профила заедно с всички данни и настройки.',
    'purge_successful' => 'Успешно изчистени фирмени данни',
    'forbidden' => 'Забранено',
    'purge_data_message' => 'Внимание: Това ще изтрие данните перманентно без възможност за възстановяване.',
    'contact_phone' => 'Телефон за връзка',
    'contact_email' => 'Имейл за връзка',
    'reply_to_email' => 'Reply-To Email',
    'reply_to_email_help' => 'Определете reply-to адрес за клиентски имейли.',
    'bcc_email_help' => 'Включи този адрес в клиентските имейли като скрито копие.',
    'import_complete' => 'Импортът завърши успешно.',
    'confirm_account_to_import' => 'Моля потвърдете профила си, за да импортирате данни.',
    'import_started' => 'Импортът е стартиран. Ще Ви изпратим имейл, когато завърши.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Гласови команди',
    'sample_commands' => 'Примерни команди',
    'voice_commands_feedback' => 'Работим активно за подобряване на тази функционалност. Ако има команда, която желаете да бъде поддържана, моля изпратете ни имейл на :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Паричен превод',
    'archived_products' => 'Успешно архивирани :count продукта',
    'recommend_on' => 'Препоръчваме <b>да активирате</b> тази настройка.',
    'recommend_off' => 'Препоръчваме <b>да деактивирате</b> тази настройка.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Етикет допълнителна такса',
    'contact_fields' => 'Полета за контакти',
    'custom_contact_fields_help' => 'Добавете поле при създаване на контакт и по желание изведете етикета и стойността в PDF документа.',
    'datatable_info' => 'Полазване от :start до :end от :total записа',
    'credit_total' => 'Общ кредит',
    'mark_billable' => 'Маркирай за плащане',
    'billed' => 'Billed',
    'company_variables' => 'Променливи Фирма',
    'client_variables' => 'Променливи Клиенти',
    'invoice_variables' => 'Променливи Фактури',
    'navigation_variables' => 'Променливи Навигация',
    'custom_variables' => 'Персонализирани променливи ',
    'invalid_file' => 'Невалиден тип файл',
    'add_documents_to_invoice' => 'Добавяне на документ към фактура',
    'mark_expense_paid' => 'Маркирай като платено',
    'white_label_license_error' => 'Грешка при валидиране на лиценза. Проверете storage/logs/laravel-error.log за повече подробности.',
    'plan_price' => 'Цена на плана',
    'wrong_confirmation' => 'Некоректен код за потвърждение',
    'oauth_taken' => 'Този профил вече съществува',
    'emailed_payment' => 'Успешно изпратен имейл за плащане',
    'email_payment' => 'Имейл за плащане',
    'invoiceplane_import' => 'Използвайте :link за да мигрирате данните си от InvoicePlane.',
    'duplicate_expense_warning' => 'Внимание: Това :link може да е дублиран документ',
    'expense_link' => 'разход',
    'resume_task' => 'Продължаване на задачата',
    'resumed_task' => 'Успешно възобновяване на работата по задачата',
    'quote_design' => 'Дизайн на оферта',
    'default_design' => 'Стандартен дизайн',
    'custom_design1' => 'Персонализиран дизайн 1',
    'custom_design2' => 'Персонализиран дизайн 2',
    'custom_design3' => 'Персонализиран дизайн 3',
    'empty' => 'Празно',
    'load_design' => 'Зареждане на дизайн',
    'accepted_card_logos' => 'Лога на приемани карти',
    'phantomjs_local_and_cloud' => 'Използване на локална PhantomJS, резервно ползване на phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Проследяване на плащанията чрез :link',
    'start_date_required' => 'Началната дата е задължителна',
    'application_settings' => 'Настройки на приложението',
    'database_connection' => 'Връзка с базата данни',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Тест на връзката',
    'from_name' => 'От - Име',
    'from_address' => 'От - Адрес',
    'port' => 'Порт',
    'encryption' => 'Криптиране',
    'mailgun_domain' => 'Mailgun домейн',
    'mailgun_private_key' => 'Mailgun частен ключ',
    'send_test_email' => 'Изпращане на тестов имейл',
    'select_label' => 'Избор на етикет',
    'label' => 'Етикет',
    'service' => 'Услуга',
    'update_payment_details' => 'Промяна на данни за плащане',
    'updated_payment_details' => 'Успешно променени данни за плащане',
    'update_credit_card' => 'Промяна на кредитна карта',
    'recurring_expenses' => 'Повтарящи се разходи',
    'recurring_expense' => 'Повтарящ се разход',
    'new_recurring_expense' => 'Нов повтарящ се разход',
    'edit_recurring_expense' => 'Редакция на повтарящ се разход',
    'archive_recurring_expense' => 'Архивиране на повтарящ се разход',
    'list_recurring_expense' => 'Списък повтарящи се разходи',
    'updated_recurring_expense' => 'Успешна актуализация на повтарящ се разход',
    'created_recurring_expense' => 'Успешно създаден повтарящ се разход',
    'archived_recurring_expense' => 'Успешно архивиран повтарящ се разход',
    'restore_recurring_expense' => 'Възстановяване на повтарящ се разход',
    'restored_recurring_expense' => 'Успешно възстановен повтарящ се разход',
    'delete_recurring_expense' => 'Изтриване на повтарящ се разход',
    'deleted_recurring_expense' => 'Успешно изтрит проект',
    'view_recurring_expense' => 'Преглед на повтарящ се разход',
    'taxes_and_fees' => 'Данъци и такси',
    'import_failed' => 'Грешка при импорт',
    'recurring_prefix' => 'Префикс за периодични документи',
    'options' => 'Настройки',
    'credit_number_help' => 'Определете прфикс или използвайте персонализиран шаблон за динамично присвояване на номера за кредитни известия.',
    'next_credit_number' => 'Следващият номер за кредитно известие е :number.',
    'padding_help' => 'Брой нули за номера',
    'import_warning_invalid_date' => 'Внимание: Невалиден формат на датата.',
    'product_notes' => 'Бележки за продукта',
    'app_version' => 'Версия на приложението',
    'ofx_version' => 'OFX версия',
    'gateway_help_23' => ':link за получаване на Stripe API ключове.',
    'error_app_key_set_to_default' => 'Грешка: APP_KEY е със стойност по подразбиране. За да го актуализирате архивирайте своята база данни и след това стартирайте <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Такса за закъснение',
    'late_fee_amount' => 'Стойност на таксата за закъснение',
    'late_fee_percent' => 'Процент на таксата за закъснение',
    'late_fee_added' => 'Такса за закъснение добавена на :date',
    'download_invoice' => 'Изтегляне на фактура',
    'download_quote' => 'Изтегляне на оферта',
    'invoices_are_attached' => 'PDF файловете на фактурите са прикачени.',
    'downloaded_invoice' => 'Ще бъде изпратен имейл с фактурата в PDF формат',
    'downloaded_quote' => 'Ще бъде изпратен имейл с офертата в PDF формат',
    'downloaded_invoices' => 'Ще бъде изпратен имейл с фактураите в PDF формат',
    'downloaded_quotes' => 'Ще бъде изпратен имейл с офертите в PDF формат',
    'clone_expense' => 'Копиране на разход',
    'default_documents' => 'Документи по подразбиране',
    'send_email_to_client' => 'Изпращане на имейл на клиента',
    'refund_subject' => 'Обработено връщане',
    'refund_body' => 'Обработено връщане на :amount за фактура :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Български Лев',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Арменски Драм',
    'currency_azerbaijan_manat' => 'Азърбейджански Манат',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Босна и Хрцеговина Конвертируема Марка',
    'currency_belarusian_ruble' => 'Беларуска Рубла',
    'currency_moldovan_leu' => 'Молдовски Леу',
    'currency_kazakhstani_tenge' => 'Казахстанска Тенге',
    'currency_gibraltar_pound' => 'Гибралтарски Паунд',

    'review_app_help' => 'Надяваме се, че използвате приложението с удоволствие.<br/>Ще се радваме, ако решите да :link!',
    'writing_a_review' => 'напишете оценка',

    'use_english_version' => 'Убедете се, че използвате английската версия на файловете.<br/>Ние ползваме заглавния ред за засичане на полетата.',
    'tax1' => 'Първи данък',
    'tax2' => 'Втори данък',
    'fee_help' => 'Таксите на портала са разходите начислявани за достъп до финансовите мрежи, в които се обработват онлайн разплащанията.',
    'format_export' => 'Формат за експорт',
    'custom1' => 'Първа колона',
    'custom2' => 'Втора колона',
    'contact_first_name' => 'Контакт - Име',
    'contact_last_name' => 'Контакт - Фамилия',
    'contact_custom1' => 'Контакт - Първа колона',
    'contact_custom2' => 'Контакт - Втора колона',
    'currency' => 'Валута',
    'ofx_help' => 'За проследяване на проблема вижте коментарите на :ofxhome_link и тествайте с :ofxget_link.',
    'comments' => 'коментари',

    'item_product' => 'Ред Продукт',
    'item_notes' => 'Ред Забележка',
    'item_cost' => 'Ред Цена',
    'item_quantity' => 'Ред Количество',
    'item_tax_rate' => 'Ред Данъчна ставка',
    'item_tax_name' => 'Ред Данък',
    'item_tax1' => 'Ред Данък 1',
    'item_tax2' => 'Ред Данък 2',

    'delete_company' => 'Изтриване на фирма',
    'delete_company_help' => 'Перманентно изтриване на фирмата заедно с всички данни и настройки.',
    'delete_company_message' => 'Внимание: Това ще изтрие перманентно фирматаВи без възможност за възстановяване.',

    'applied_discount' => 'Ваучерът е приложен, цената на плана е редуцирана с :discount%.',
    'applied_free_year' => 'Ваучерът е приложен, Вашият профил е ъпгрейднат до Pro за една година.',

    'contact_us_help' => 'Ако съобщавате за грешка, моля приложете всички релевантни логове от storage/logs/laravel-error.log',
    'include_errors' => 'Включи грешките',
    'include_errors_help' => 'Включи :link от storage/logs/laravel-error.log',
    'recent_errors' => 'текущи грешки',
    'customer' => 'Клиент',
    'customers' => 'Клиенти',
    'created_customer' => 'Успешно създаден клиент',
    'created_customers' => 'Успешно създадени :count клиенти',

    'purge_details' => 'Данните във Вашата фирма (:account) са изчистени успешно.',
    'deleted_company' => 'Успешно изтриване на фирма',
    'deleted_account' => 'Успешно прекратен акаунт',
    'deleted_company_details' => 'Вашата фирма (:account) е изтрита успешно.',
    'deleted_account_details' => 'Вашият профил (:account) е изтрит успешно.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Приемане на Alipay',
    'enable_sofort' => 'Приемане на банкови преводи от ЕС',
    'stripe_alipay_help' => 'Тези портали трябва също да бъдат активирани в :link.',
    'calendar' => 'Календар',
    'pro_plan_calendar' => ':link за активиране на календара с преминаване към план Pro',

    'what_are_you_working_on' => 'Върху какво работите?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Опресняване',
    'filter_sort' => 'Филтриране/Сортиране',
    'no_description' => 'Без описание',
    'time_tracker_login' => 'Вход в Time Tracker',
    'save_or_discard' => 'Запис или отмяна на промените',
    'discard_changes' => 'Отмяна на промените',
    'tasks_not_enabled' => 'Задачите не са активирани.',
    'started_task' => 'Успешно стартирана задача',
    'create_client' => 'Създаване на клиент',

    'download_desktop_app' => 'Изтегляне на приложението за десктоп',
    'download_iphone_app' => 'Изтегляне на приложението за iPhone',
    'download_android_app' => 'Изтегляне на приложението за Android',
    'time_tracker_mobile_help' => 'Докоснете двукратно задачата, за да я изберете',
    'stopped' => 'Спряна',
    'ascending' => 'Нарастващо',
    'descending' => 'Намаляващо',
    'sort_field' => 'Сортиране по',
    'sort_direction' => 'Посока',
    'discard' => 'Отказ',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'мин.',
    'time_hr' => 'ч.',
    'time_hrs' => 'ч.',
    'clear' => 'Изчистване',
    'warn_payment_gateway' => 'Забележка: Приемането на онлайн плащания изисква платежен портал, :link за добавяне.',
    'task_rate' => 'Ставка',
    'task_rate_help' => 'Заложете ставка за фактуриране по подразбиране.',
    'past_due' => 'Просрочено',
    'document' => 'Документ',
    'invoice_or_expense' => 'Фактура / Разход',
    'invoice_pdfs' => 'Фактури в PDF',
    'enable_sepa' => 'Приемане на SEPA плащания',
    'enable_bitcoin' => 'Приемане на Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Като предоставяте своя IBAN и потвърждавате това плащане, упълномощавате :company и Stripe, нашия доставчик на платежни услуги, да изпратят указания на банката Ви за дебитиране на сметката Ви и банката Ви за дебитиране на сметката Ви в съответствие с тези инструкции. Имате право на възстановяване на сумата от банката съгласно условията на споразумението с Вашата банка. Възстановяването трябва да бъде заявено в рамките на 8 седмици, считано от датата на дебитиране на сметката Ви.',
    'recover_license' => 'Възстановяване на лиценз',
    'purchase' => 'Покупка',
    'recover' => 'Възстановяване',
    'apply' => 'Приложи',
    'recover_white_label_header' => 'Възстановяване на лиценз White Label',
    'apply_white_label_header' => 'Прилагане на лиценз White Label',
    'videos' => 'Видео',
    'video' => 'Видео',
    'return_to_invoice' => 'Назад към фактурата',
    'gateway_help_13' => 'За да използвате ITN оставете полето PDT Key празно.',
    'partial_due_date' => 'Частичен падеж',
    'task_fields' => 'Полета за задачи',
    'product_fields_help' => 'Използвайте "Drag and drop" за промяна реда на полетата',
    'custom_value1' => 'Персонифицирана стойност',
    'custom_value2' => 'Персонифицирана стойност',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Използвайте телефона си, за да потвърдите идентичността си при вход',
    'two_factor_setup' => 'Настроване на Two-Factor Authentication',
    'two_factor_setup_help' => 'Сканирайте баркода с :link съвместимо приложение.',
    'one_time_password' => 'Еднократна парола',
    'set_phone_for_two_factor' => 'Въведете мобилния си номер като резервен вариант.',
    'enabled_two_factor' => 'Успешно активирана Two-Factor Authentication',
    'add_product' => 'Добавяне на продукт',
    'email_will_be_sent_on' => 'Забележка: Имейлът ще бъде изпратен на :date.',
    'invoice_product' => 'Фактуриране на продукт',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Грешка: Невъзможно локално съхраняване.',
    'your_password_reset_link' => 'Линк за нулиране на паролата',
    'subdomain_taken' => 'Този суб-домейн вече се използва.',
    'client_login' => 'Вход за клиенти',
    'converted_amount' => 'Конвертирана сума',
    'default' => 'По подразбиране',
    'shipping_address' => 'Адрес за доставка',
    'bllling_address' => 'Адрес за фактуриране',
    'billing_address1' => 'Фактура - Улица',
    'billing_address2' => 'Фактура - Ап.',
    'billing_city' => 'Фактура - Град',
    'billing_state' => 'Фактура - Щат/Провинция',
    'billing_postal_code' => 'Фактура - Пощ. код',
    'billing_country' => 'Фактура - Държава',
    'shipping_address1' => 'Доставка - Улица',
    'shipping_address2' => 'Доставка - Ап.',
    'shipping_city' => 'Доставка - Град',
    'shipping_state' => 'Доставка - Щат/Провинция',
    'shipping_postal_code' => 'Доставка - Пощ. код',
    'shipping_country' => 'Доставка - Държава',
    'classify' => 'Класифициране',
    'show_shipping_address_help' => 'Изискване клиента да предостави адрес за доставка',
    'ship_to_billing_address' => 'Доставка до адреса за фактуриране',
    'delivery_note' => 'Документ за доставка',
    'show_tasks_in_portal' => 'Показване на задачите в клиентския портал',
    'cancel_schedule' => 'Отмяна на график',
    'scheduled_report' => 'Справка по график',
    'scheduled_report_help' => 'Изпращане на справка :report като :format на :email',
    'created_scheduled_report' => 'Успешно зададен график за справка',
    'deleted_scheduled_report' => 'Успешно отменен график на справка',
    'scheduled_report_attached' => 'Вашата справка по график :type е прикачена.',
    'scheduled_report_error' => 'Грешка при изготвяне на справка по график',
    'invalid_one_time_password' => 'Невалидна еднократна парола',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Приемане на Apple Pay и Pay with Google',
    'requires_subdomain' => 'Този тип плащане изисква :link.',
    'subdomain_is_set' => 'субдомейн е заложен',
    'verification_file' => 'Верификационен файл',
    'verification_file_missing' => 'Верификационният файл е необходим за приемане на плащания.',
    'apple_pay_domain' => 'Използвайте <code>:domain</code> като домейн в :link.',
    'apple_pay_not_supported' => 'За съжаление Apple/Google Pay не се поддърба във Вашия браузър',
    'optional_payment_methods' => 'Допълнителни методи за плащане',
    'add_subscription' => 'Добавяне на абонамент',
    'target_url' => 'Target',
    'target_url_help' => 'При настъпване на избраното събитие приложението ще публикува обекта в целевия URL адрес.',
    'event' => 'Събитие',
    'subscription_event_1' => 'Създаден клиент',
    'subscription_event_2' => 'Създадена фактура',
    'subscription_event_3' => 'Създадена оферта',
    'subscription_event_4' => 'Създадено плащане',
    'subscription_event_5' => 'Създаден доставчик',
    'subscription_event_6' => 'Актуализирана оферта',
    'subscription_event_7' => 'Изтрита оферта',
    'subscription_event_8' => 'Актуализирана фактура',
    'subscription_event_9' => 'Изтрита фактура',
    'subscription_event_10' => 'Актуализиран клиент',
    'subscription_event_11' => 'Изтрит клиент',
    'subscription_event_12' => 'Изтрито плащане',
    'subscription_event_13' => 'Актуализиран доставчик',
    'subscription_event_14' => 'Изтрит доставчик',
    'subscription_event_15' => 'Създаден разход',
    'subscription_event_16' => 'Актуализиран разход',
    'subscription_event_17' => 'Изтрит разход',
    'subscription_event_18' => 'Създадена задача',
    'subscription_event_19' => 'Актуализирана задача',
    'subscription_event_20' => 'Изтрита задача',
    'subscription_event_21' => 'Одобрена оферта',
    'subscriptions' => 'Абонаменти',
    'updated_subscription' => 'Успешно редактиран абонамент',
    'created_subscription' => 'Успешно създаден абонамент',
    'edit_subscription' => 'Редакция абонамент',
    'archive_subscription' => 'Архивирай абонамент',
    'archived_subscription' => 'Успешно архивиране на абонамент',
    'project_error_multiple_clients' => 'Проектът не може да бъде присвоен на различни клиенти',
    'invoice_project' => 'Фактуриране на проект',
    'module_recurring_invoice' => 'Периодични фактури',
    'module_credit' => 'Кредитни известия',
    'module_quote' => 'Оферти и предложения',
    'module_task' => 'Задачи и проекти',
    'module_expense' => 'Разходи и доставчици',
    'module_ticket' => 'Tickets',
    'reminders' => 'Напомняния',
    'send_client_reminders' => 'Изпращане на напомняния по имейл',
    'can_view_tasks' => 'Задачите са достъпни в портала',
    'is_not_sent_reminders' => 'Напомняния не са изпращани',
    'promotion_footer' => 'Вашата промоция скоро ще изтече, :link за ъпгрейд.',
    'unable_to_delete_primary' => 'Забележка: За да изтриете тази фирма първо трябва да изтриете всички свързани фирми.',
    'please_register' => 'Моля, регистрирайте профила си',
    'processing_request' => 'Обработка на заявката',
    'mcrypt_warning' => 'Внимание: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Промяна на часове',
    'inclusive_taxes_help' => 'Включване на<b>данъка в разходите</b>',
    'inclusive_taxes_notice' => 'Тази настройка не може да бъде променена след издаване на фактурата.',
    'inclusive_taxes_warning' => 'Внимание: Наличните фактури ще трябва да бъдат съхранени отново.',
    'copy_shipping' => 'Копиране на адрес за доставка',
    'copy_billing' => 'Копиране на адрес за фактуриране',
    'quote_has_expired' => 'Офертата е изтекла. Моля, свържете се с доставчика.',
    'empty_table_footer' => 'Показване от 0 до 0 от 0 записа',
    'do_not_trust' => 'Не запомняй това устройство',
    'trust_for_30_days' => 'Доверие за 30 дни',
    'trust_forever' => 'Доверие завинаги',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Добави статус',
    'archive_status' => 'Архивирай статус',
    'new_status' => 'Нов статус',
    'convert_products' => 'Конвертиране на продукти',
    'convert_products_help' => 'Автоматично конвертиране на цените на продуктите във валутата на клиента',
    'improve_client_portal_link' => 'Въведете субдомейн за да съкратите адреса на клиентския портал.',
    'budgeted_hours' => 'Часове по бюджет',
    'progress' => 'Прогрес',
    'view_project' => 'Нов проект',
    'summary' => 'Обобщение',
    'endless_reminder' => 'Безкрайно подсещане',
    'signature_on_invoice_help' => 'Въведете този код за извеждане на подписа на клиента в PDF документа.',
    'signature_on_pdf' => 'Показване в PDF документа',
    'signature_on_pdf_help' => 'Показване на подписа на клиента в PDF фактурата / офертата.',
    'expired_white_label' => 'Лицензът White Label е изтекъл',
    'return_to_login' => 'Обратно към формуляра за вход',
    'convert_products_tip' => 'Забележка: Добавете :link с име ":name" за извеждане на валутния курс.',
    'amount_greater_than_balance' => 'Сумата е по-голяма от общата стойност на фактурата. Ще бъде създаден кредитен запис с оставащата сума.',
    'custom_fields_tip' => 'Използвайте <code>Етикет|Опция1,Опция2</code> за показване на падащо меню.',
    'client_information' => 'Информация за клиента',
    'updated_client_details' => 'Данните на клиента са актуализирани успешно.',
    'auto' => 'Авто',
    'tax_amount' => 'Такса',
    'tax_paid' => 'Платена такса',
    'none' => 'Няма',
    'proposal_message_button' => 'СумаЗа да видите своето предложение за :amount, отворете линка по-долу.',
    'proposal' => 'Предложение',
    'proposals' => 'Предложения',
    'list_proposals' => 'Списък предложения',
    'new_proposal' => 'Ново предложение',
    'edit_proposal' => 'Редакция на предложение',
    'archive_proposal' => 'Архивиране на предложение',
    'delete_proposal' => 'Изтриване на предложение',
    'created_proposal' => 'Успешно създадено предложение',
    'updated_proposal' => 'Успешно актуализирано предложение',
    'archived_proposal' => 'Успешно архивирано предложение',
    'deleted_proposal' => 'Успешно архивирано предложение',
    'archived_proposals' => 'Успешно архивирани :count предложения',
    'deleted_proposals' => 'Успешно архивирани :count предложения',
    'restored_proposal' => 'Успешно възстановено предложение',
    'restore_proposal' => 'Възстановяване на предложение',
    'snippet' => 'Фрагмент',
    'snippets' => 'Фрагменти',
    'proposal_snippet' => 'Фрагмент',
    'proposal_snippets' => 'Фрафменти',
    'new_proposal_snippet' => 'Нов фрагмент',
    'edit_proposal_snippet' => 'Редакция на фрагмент',
    'archive_proposal_snippet' => 'Архивиране на фрагмент',
    'delete_proposal_snippet' => 'Изтриване на фрагмент',
    'created_proposal_snippet' => 'Успешно създаден фрагмент',
    'updated_proposal_snippet' => 'Успешно актуализиран фрагмент',
    'archived_proposal_snippet' => 'Успешно архивиран фрагмент',
    'deleted_proposal_snippet' => 'Успешно архивиран фрагмент',
    'archived_proposal_snippets' => 'Успешно архивирани :count фрагмента',
    'deleted_proposal_snippets' => 'Успешно архивирани :count фрагмента',
    'restored_proposal_snippet' => 'Успешно възстановен фрагмент',
    'restore_proposal_snippet' => 'Възстановяване на фрагмент',
    'template' => 'Шаблон',
    'templates' => 'Шаблони',
    'proposal_template' => 'Шаблон',
    'proposal_templates' => 'Шаблони',
    'new_proposal_template' => 'Нов шаблон',
    'edit_proposal_template' => 'Редакция на шаблон',
    'archive_proposal_template' => 'Архивиране на шаблон',
    'delete_proposal_template' => 'Изтриване на шаблон',
    'created_proposal_template' => 'Успешно създаден шаблон',
    'updated_proposal_template' => 'Успешно актуализиран шаблон',
    'archived_proposal_template' => 'Успешно архивиран шаблон',
    'deleted_proposal_template' => 'Успешно архивиран шаблон',
    'archived_proposal_templates' => 'Успешно архивирани :count шаблона',
    'deleted_proposal_templates' => 'Успешно архивирани :count шаблона',
    'restored_proposal_template' => 'Успешно възстановен шаблон',
    'restore_proposal_template' => 'Възстановяване на шаблон',
    'proposal_category' => 'Категория',
    'proposal_categories' => 'Категории',
    'new_proposal_category' => 'Нова категория',
    'edit_proposal_category' => 'Редактирай категория',
    'archive_proposal_category' => 'Архивирай категория',
    'delete_proposal_category' => 'Изтрий категория',
    'created_proposal_category' => 'Успешно създадена категория',
    'updated_proposal_category' => 'Успешно актуализирана категория',
    'archived_proposal_category' => 'Успешно архивирана категория',
    'deleted_proposal_category' => 'Успешно архивирана категория',
    'archived_proposal_categories' => 'Успешно архивирани :count категории',
    'deleted_proposal_categories' => 'Успешно архивирани :count категории',
    'restored_proposal_category' => 'Успешно възстановена категория',
    'restore_proposal_category' => 'Възстановяване на категория',
    'delete_status' => 'Изртрий статус',
    'standard' => 'Стандартно',
    'icon' => 'Икона',
    'proposal_not_found' => 'Исканото предложение не е налично',
    'create_proposal_category' => 'Добави категория',
    'clone_proposal_template' => 'Копиране на шаблон',
    'proposal_email' => 'Имейл на Предложение',
    'proposal_subject' => 'Ново предложение :number от :account',
    'proposal_message' => 'За да видите своето предложение за :amount, отворете линка по-долу.',
    'emailed_proposal' => 'Успешно изпратено предложение по имейл',
    'load_template' => 'Зареждане на шаблон',
    'no_assets' => 'Без изображения, завлачете за качване',
    'add_image' => 'Добави картинка',
    'select_image' => 'Избери картинка',
    'upgrade_to_upload_images' => 'Надградете до план Enterprise за качване на изображения',
    'delete_image' => 'Изтриване на изображение',
    'delete_image_help' => 'Внимание: Изтриването на изображението ще го премахне от всички предложения.',
    'amount_variable_help' => 'Забележка: Полето $amount във фактурата ще използва полето частично/депозит, ако е заложено; иначе ще използва баланса по фактурата.',
    'taxes_are_included_help' => 'Завележка: Включените данъци са активирани.',
    'taxes_are_not_included_help' => 'Завележка: Включените данъци не са активирани.',
    'change_requires_purge' => 'Промяната на тази настройка изисква :link данните на профила.',
    'purging' => 'изчистване',
    'warning_local_refund' => 'Възстановяването на сумата ще бъде записано в приложението, но НЯМА да бъде обработено от платежния портал.',
    'email_address_changed' => 'Имейл адреса беше променен',
    'email_address_changed_message' => 'Имейл адреса на вашия акаунт беше променен от:old_email на: new_email.',
    'test' => 'Тест',
    'beta' => 'Бета',
    'gmp_required' => 'Експортирането към ZIP изисква GMP разширение',
    'email_history' => 'История на имейлите',
    'loading' => 'Зареждане',
    'no_messages_found' => 'Няма съобщения',
    'processing' => 'Обработка',
    'reactivate' => 'Реактивиране',
    'reactivated_email' => 'Имейл адресът е реактивиран',
    'emails' => 'Имейли',
    'opened' => 'Отворени',
    'bounced' => 'Върнати',
    'total_sent' => 'Общо изпратени',
    'total_opened' => 'Общо отворени',
    'total_bounced' => 'Общо върнати',
    'total_spam' => 'Общо спам',
    'platforms' => 'Платформи',
    'email_clients' => 'Имейли на клиенти',
    'mobile' => 'Мобилно',
    'desktop' => 'Десктоп',
    'webmail' => 'Webmail',
    'group' => 'Групиране',
    'subgroup' => 'Подгрупа',
    'unset' => 'Изчистване',
    'received_new_payment' => 'Получихте ново плащане!',
    'slack_webhook_help' => 'Получаване на известия за плащане чрез :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Приемам',
    'accepted_terms' => 'Успешно пиети последни условия',
    'invalid_url' => 'Невалиден URL',
    'workflow_settings' => 'Настройки на работния процес',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Автоматично изпращане на периодични фактури при създаването им',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Автоматично архивиране на фактури при плащането им',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Автоматично архивиране на оферти при конвертирането им',
    'require_approve_quote' => 'Изискване на одобрение на офертата',
    'require_approve_quote_help' => 'Клиентите трябва да одобрят офертите.',
    'allow_approve_expired_quote' => 'Разрешено одобрение на изтекли оферти',
    'allow_approve_expired_quote_help' => 'Клиентите могат да одобряват оферти с изтекъл срок.',
    'invoice_workflow' => 'Работен процес - Фактури',
    'quote_workflow' => 'Работен процес - Оферти',
    'client_must_be_active' => 'Грешка: Клиентът трябва да бъде активен.',
    'purge_client' => 'Изчистване на клиент',
    'purged_client' => 'Успешно изчистен клиент',
    'purge_client_warning' => 'Всички свързани записи (фактури, задачи, разходи, документи и др.) също ще бъдат изтрити.',
    'clone_product' => 'Копиране на продукт',
    'item_details' => 'Детайли на реда',
    'send_item_details_help' => 'Изпращане на детайлите на реда към платежния портал.',
    'view_proposal' => 'Преглед на Предложението',
    'view_in_portal' => 'Вижте в портала',
    'cookie_message' => 'Този сайт използва бисквитки за да осигури получаването на най-добрата за Вас функционалност на сайта ни.',
    'got_it' => 'Разбрах!',
    'vendor_will_create' => 'доставчик ще бъде създаден',
    'vendors_will_create' => 'доставчици ще бъдат създадени',
    'created_vendors' => 'Успешно създаден(и) :count доставчик/ци',
    'import_vendors' => 'Импортиране на доставчици',
    'company' => 'Фирма',
    'client_field' => 'Поле на клиента',
    'contact_field' => 'Поле за контакти',
    'product_field' => 'Поле на продукта',
    'task_field' => 'Поле Задача',
    'project_field' => 'Поле на проекта',
    'expense_field' => 'Поле Разход',
    'vendor_field' => 'Поле на доставчика',
    'company_field' => 'Поле на Фирмата',
    'invoice_field' => 'Поле на фактурата',
    'invoice_surcharge' => 'Допълнителна такса по фактура',
    'custom_task_fields_help' => 'Добавете поле, когато създавате задача.',
    'custom_project_fields_help' => 'Добави поле при създаване на проект',
    'custom_expense_fields_help' => 'Добавете поле, когато създавате разход.',
    'custom_vendor_fields_help' => 'Добави поле при създаване на доствчик',
    'messages' => 'Съобщения',
    'unpaid_invoice' => 'Неплатена фактура',
    'paid_invoice' => 'Платена фактура',
    'unapproved_quote' => 'Неодобрена оферта',
    'unapproved_proposal' => 'Неодобрено предложение',
    'autofills_city_state' => 'Автоматично попълване град/щат',
    'no_match_found' => 'Няма съвпадения',
    'password_strength' => 'Сложност на паролата',
    'strength_weak' => 'Слаба',
    'strength_good' => 'Добра',
    'strength_strong' => 'Силна',
    'mark' => 'Маркирай',
    'updated_task_status' => 'Успешно променен статус на задача',
    'background_image' => 'Фоново изображение',
    'background_image_help' => 'Използвайте :link за управление на Вашите изображения. Препоръчваме използването на малки файлове.',
    'proposal_editor' => 'редактор на предложения',
    'background' => 'Фон',
    'guide' => 'Ръководство',
    'gateway_fee_item' => 'Такса на портала',
    'gateway_fee_description' => 'Допълнителна такса на портала',
    'gateway_fee_discount_description' => 'Отстъпка от таксата на портала',
    'show_payments' => 'Покажи Плащанията',
    'show_aging' => 'Покажи забавени',
    'reference' => 'Референция',
    'amount_paid' => 'Платена сума',
    'send_notifications_for' => 'Изпращане на известия за',
    'all_invoices' => 'Всички фактури',
    'my_invoices' => 'Мои фактури',
    'payment_reference' => 'Параметри на плащането',
    'maximum' => 'Максимум',
    'sort' => 'Сортиране',
    'refresh_complete' => 'Обновяването завършено',
    'please_enter_your_email' => 'Моля въведете вашият имейл',
    'please_enter_your_password' => 'Моля въведете вашата парола',
    'please_enter_your_url' => 'Моля, въведете своя URL',
    'please_enter_a_product_key' => 'Моля, въведете product key',
    'an_error_occurred' => 'Настъпила е грешка',
    'overview' => 'Преглед',
    'copied_to_clipboard' => 'Копирано :value в клипборда',
    'error' => 'Грешка',
    'could_not_launch' => 'Не може да стартира',
    'additional' => 'Допълнително',
    'ok' => 'Ок',
    'email_is_invalid' => 'Имейл адресът е невалиден',
    'items' => 'Редове',
    'partial_deposit' => 'Частично/Депозит',
    'add_item' => 'Добавяне на ред',
    'total_amount' => 'Обща стойност',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Статус на фактурите',
    'click_plus_to_add_item' => 'Натиснете + за добавяне на ред',
    'count_selected' => ':count избрани',
    'dismiss' => 'Отхвърляне',
    'please_select_a_date' => 'Моля изберете дата',
    'please_select_a_client' => 'Моля изберете клиент',
    'language' => 'Език',
    'updated_at' => 'Актуализиран',
    'please_enter_an_invoice_number' => 'Моля, въведете номер на фактура',
    'please_enter_a_quote_number' => 'Моля, въведете номер на оферта',
    'clients_invoices' => 'фактури на :client',
    'viewed' => 'Прегледано',
    'approved' => 'Одобрено',
    'invoice_status_1' => 'Чернова',
    'invoice_status_2' => 'Изпратено',
    'invoice_status_3' => 'Прегледана',
    'invoice_status_4' => 'Одобрена',
    'invoice_status_5' => 'Частично',
    'invoice_status_6' => 'Платена',
    'marked_invoice_as_sent' => 'Фактурата е успешно маркирана като изпратена',
    'please_enter_a_client_or_contact_name' => 'Моля, въведете клиент или лице за контакт',
    'restart_app_to_apply_change' => 'Рестартирайте приложението за прилагане на промяната',
    'refresh_data' => 'Опресняване на данни',
    'blank_contact' => 'Празен контакт',
    'no_records_found' => 'Няма намерени записи',
    'industry' => 'Бранш',
    'size' => 'Размер',
    'net' => 'Нето',
    'show_tasks' => 'Показване на задачи',
    'email_reminders' => 'Изпращане на напомняния по имейл',
    'reminder1' => 'Първо напомняне',
    'reminder2' => 'Второ напомняне',
    'reminder3' => 'ТЪрето напомняне',
    'send' => 'Изпращане',
    'auto_billing' => 'Auto billing',
    'button' => 'Бутон',
    'more' => 'Още',
    'edit_recurring_invoice' => 'Редакция на периодична фактура',
    'edit_recurring_quote' => 'Редакция на периодична оферта',
    'quote_status' => 'Статус на оферта',
    'please_select_an_invoice' => 'Моля, изберете фактура',
    'filtered_by' => 'Филтрирано по',
    'payment_status' => 'Статус на Плащането',
    'payment_status_1' => 'Изчакващи',
    'payment_status_2' => 'Анулирани',
    'payment_status_3' => 'Грешни',
    'payment_status_4' => 'Готови',
    'payment_status_5' => 'Частично възстановяване',
    'payment_status_6' => 'Възстановена',
    'send_receipt_to_client' => 'Изпращане на разписка на клиента',
    'refunded' => 'Възстановена',
    'marked_quote_as_sent' => 'Офертата е успешно маркирана като изпратена',
    'custom_module_settings' => 'Настройки на персонален модул',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'Нов Ticket',
    'edit_ticket' => 'Редакция на Ticket',
    'view_ticket' => 'Преглед на Ticket',
    'archive_ticket' => 'Архивиране на Ticket',
    'restore_ticket' => 'Възстановяване на Ticket',
    'delete_ticket' => 'Изтриване на Ticket',
    'archived_ticket' => 'Успешно архивиран Ticket',
    'archived_tickets' => 'Успешно архивирани Tickets',
    'restored_ticket' => 'Успешно възстановен Ticket',
    'deleted_ticket' => 'Успешно изтрит Ticket',
    'open' => 'Open',
    'new' => 'Нов',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Приоритет',
    'last_updated' => 'Последно актуализиран',
    'comment' => 'Забележки',
    'tags' => 'Тагове',
    'linked_objects' => 'Свързани обекти',
    'low' => 'Нисък',
    'medium' => 'Среден',
    'high' => 'Висок',
    'no_due_date' => 'Няма заложена дата за изпълнение',
    'assigned_to' => 'Присвоен на',
    'reply' => 'Отговор',
    'awaiting_reply' => 'Очаква отговор',
    'ticket_close' => 'Затваряне на Ticket',
    'ticket_reopen' => 'Повторно отваряне на Ticket',
    'ticket_open' => 'Отваряне на Ticket',
    'ticket_split' => 'Разделяне на Ticket',
    'ticket_merge' => 'Обединяване на Ticket',
    'ticket_update' => 'Актуализация на Ticket',
    'ticket_settings' => 'Настройки Ticket',
    'updated_ticket' => 'Актуализиран Ticket',
    'mark_spam' => 'Маркирай като спам',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Името е заето',
    'local_part_available' => 'Името е свободно',
    'local_part_invalid' => 'Невалидно име (само букви и цифри, без интервали)',
    'local_part_help' => 'Персонализирайте локалната част от Вашия имейл адрес за поддръжка, напр. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name е името на получателя / изпращача, което се изписва вместо имейл адреса му, напр. Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Център за поддръжка',
    'attachments' => 'Прикачени файлове',
    'client_upload' => 'Файлове от клиента',
    'enable_client_upload_help' => 'Клиентите могат да качват документи/файлове',
    'max_file_size_help' => 'Максималният размер на файла (KB) е лимитиран от променливите post_max_size и upload_max_filesize заложени във Вашия PHP.INI файл.',
    'max_file_size' => 'Максимален размер на файла',
    'mime_types' => 'Mime типове',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Разделен със запетая списък на разрешените mime типове. Оставете празно, за да разрешите всички.',
    'ticket_number_start_help' => 'Новерът на тикета трябва да е по-голям от номера на настоящия',
    'new_ticket_template_id' => 'Нов Ticket',
    'new_ticket_autoresponder_help' => 'Изборът на шаблон ще активира изпращането на автоматичен отговор на клиента / контакта при създаването на нов Ticket.',
    'update_ticket_template_id' => 'Актуализиран Ticket',
    'update_ticket_autoresponder_help' => 'Изборът на шаблон ще активира изпращането на автоматичен отговор на клиента / контакта при актуализирането на Ticket.',
    'close_ticket_template_id' => 'Затворен Ticket',
    'close_ticket_autoresponder_help' => 'Изборът на шаблон ще активира изпращането на автоматичен отговор на клиента / контакта при затварянето на Ticket.',
    'default_priority' => 'Приоритет по подразбиране',
    'alert_new_comment_id' => 'Нов коментар',
    'alert_comment_ticket_help' => 'С избора на шаблон ще бъде изпращано известие (към агента), когато бъде направен коментар.',
    'alert_comment_ticket_email_help' => 'Разделени със запетая имей адреси за bcc при нов коментар.',
    'new_ticket_notification_list' => 'Допълнителни известия за нов Ticket',
    'update_ticket_notification_list' => 'Допълнителни известия за нов коментар',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Присвояване на Ticket',
    'alert_ticket_assign_agent_id_hel' => 'Изборът на шаблон ще активира изпращането на известие (към агента), когато тикетът е присвоен.',
    'alert_ticket_assign_agent_id_notifications' => 'Допълнителни известия при присвояване на Ticket',
    'alert_ticket_assign_agent_id_help' => 'Разделени със запетая имей адреси за bcc при присвояване на Ticket.',
    'alert_ticket_transfer_email_help' => 'Разделени със запетая имей адреси за bcc при трансфер на Ticket.',
    'alert_ticket_overdue_agent_id' => 'Просрочие на Ticket',
    'alert_ticket_overdue_email' => 'Допълнителни известия за просрочен Ticket',
    'alert_ticket_overdue_email_help' => 'Разделени със запетая имей адреси за bcc при просрочие на Ticket.',
    'alert_ticket_overdue_agent_id_help' => 'С избора на шаблон ще бъде изпращано известие (към агента), когато тикетът стане просрочен.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Може да присвоява и да прехвърля тикети. Присвоен като агент по подразбиране за всички тикети.',
    'default_agent' => 'Агент по подразбиране',
    'default_agent_help' => 'Ако е избран, ще бъде присвоен на всички входящи тикет-и',
    'show_agent_details' => 'Показване на детайлите на агента при отговор',
    'avatar' => 'Аватар',
    'remove_avatar' => 'Премахване на аватар',
    'ticket_not_found' => 'Тикетът не е намерен',
    'add_template' => 'Добавяне на шаблон',
    'ticket_template' => 'Шаблон за Ticket',
    'ticket_templates' => 'Шаблони за Ticket',
    'updated_ticket_template' => 'Актуализиран шаблон за Ticket',
    'created_ticket_template' => 'Създаден шаблон за Ticket',
    'archive_ticket_template' => 'Архивиране на шаблон',
    'restore_ticket_template' => 'Възстановяване на шаблон',
    'archived_ticket_template' => 'Успешно архивиран шаблон',
    'restored_ticket_template' => 'Успешно възстановен шаблон',
    'close_reason' => 'Кажете ни, защо затваряте този тикет',
    'reopen_reason' => 'Кажете ни, защо отваряте отново този тикет',
    'enter_ticket_message' => 'Моля, въведете съобщение за да актуализирате тикет-а',
    'show_hide_all' => 'Показване / Скриване на всички',
    'subject_required' => 'Полето Относно е задължително',
    'mobile_refresh_warning' => 'Ако използвате мобилното приложение, може да трябва да направите  full refresh.',
    'enable_proposals_for_background' => 'За да качите фоново изображение :link за активиране на модула за предложения.',
    'ticket_assignment' => 'Ticket :ticket_number е присвоен на :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number е актуализиран от клиент :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number е създаден.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number е актуализиран.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number е затворен.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number вече е просрочен',
    'merge' => 'Обединяване',
    'merged' => 'Обединен',
    'agent' => 'Агент',
    'parent_ticket' => 'Родителски тикет',
    'linked_tickets' => 'Свързани тикети',
    'merge_prompt' => 'Въведете номер на Ticket, към който да бъде добавен',
    'merge_from_to' => 'Ticket #:old_ticket обединен в Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket е затворен и обединен в Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket е затворед и добавен в този',
    'merge_placeholder' => 'Обедини Ticket #:ticket в следния',
    'select_ticket' => 'Избор на Ticket',
    'new_internal_ticket' => 'Нов вътрешен Ticket',
    'internal_ticket' => 'Вътрешен Ticket',
    'create_ticket' => 'Създаване на Ticket',
    'allow_inbound_email_tickets_external' => 'Нови Tickets по имейл (клиент)',
    'allow_inbound_email_tickets_external_help' => 'Клиентите могат да създават нови Ticket по имейл',
    'include_in_filter' => 'Включи във филтъра',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Сравнение',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Вход чрез Google',
    'thanks_for_patience' => 'Благодарим Ви за търпението докато работим по въвеждането на тези функции.\n\nНадяваме се да ги завършим през следващите няколко месеца.\n\nДо тогава ще продължим поддръжката на ',
    'legacy_mobile_app' => 'Старо мобилно приложение',
    'today' => 'Днес',
    'current' => 'Настоящ',
    'previous' => 'Предишен',
    'current_period' => 'Настоящ период',
    'comparison_period' => 'Период за сравнение',
    'previous_period' => 'Предишен период',
    'previous_year' => 'Предишна година',
    'compare_to' => 'Сравнение със',
    'last_week' => 'Предишна седмица',
    'clone_to_invoice' => 'Копирай във фактура',
    'clone_to_quote' => 'Копирай в оферта',
    'convert' => 'Конвертирай',
    'last7_days' => 'Последни 7 дни',
    'last30_days' => 'Последни 30 дни',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Показване на детайлите на продукта',
    'show_product_notes_help' => 'Включване на <b>описанието и цената</b> в падащото меню за продукта',
    'important' => 'Важно',
    'thank_you_for_using_our_app' => 'Благодарим Ви, че използвате нашето приложение!',
    'if_you_like_it' => 'Ако го харесвате Ви молим',
    'to_rate_it' => 'да го оцените.',
    'average' => 'Средно',
    'unapproved' => 'Неодобрено',
    'authenticate_to_change_setting' => 'Моля, влезте в профила си за промяна на тази настойка',
    'locked' => 'Блокирано',
    'authenticate' => 'Вход в профила',
    'please_authenticate' => 'Моля, влезте в профила си',
    'biometric_authentication' => 'Биометричен вход',
    'auto_start_tasks' => 'Автоматично стартиране на задачите',
    'budgeted' => 'Бюджетирано',
    'please_enter_a_name' => 'Моля, въведете име',
    'click_plus_to_add_time' => 'Натиснете + за да добавите време',
    'design' => 'Дизайн',
    'password_is_too_short' => 'Паролата е твърде кратка',
    'failed_to_find_record' => 'Записът не е намерен',
    'valid_until_days' => 'Валидно До',
    'valid_until_days_help' => 'Автоматично установява полето <b>Валидна до</b> в оферти на посочения брой дни в бъдеще. Оставете празно, за да изключите функцията.',
    'usually_pays_in_days' => 'Дни',
    'requires_an_enterprise_plan' => 'Изисква "Enterprise" абонамент',
    'take_picture' => 'Направи Снимка',
    'upload_file' => 'Качване на Файл',
    'new_document' => 'Нов Документ',
    'edit_document' => 'Редакция на Документ',
    'uploaded_document' => 'Документът беше качен успешно',
    'updated_document' => 'Документът беше обновен успешно',
    'archived_document' => 'Документът беше архивиран успешно',
    'deleted_document' => 'Документът беше изтрит успешно',
    'restored_document' => 'Документът беше възстановен успешно',
    'no_history' => 'Няма История',
    'expense_status_1' => 'Логнат',
    'expense_status_2' => 'Изчакващи',
    'expense_status_3' => 'Фактурирано',
    'no_record_selected' => 'Няма избрани записи',
    'error_unsaved_changes' => 'Моля запазете или откажете промените',
    'thank_you_for_your_purchase' => 'Благодарим за покупката!',
    'redeem' => 'Осребряване',
    'back' => 'Назад',
    'past_purchases' => 'Минали покупки',
    'annual_subscription' => 'Годишен абонамен',
    'pro_plan' => 'Pro Абонамент',
    'enterprise_plan' => 'Enterprise План',
    'count_users' => ':count потребители',
    'upgrade' => 'Обнови',
    'please_enter_a_first_name' => 'Моля въведете собствено име',
    'please_enter_a_last_name' => 'Моля въведете фамилно име',
    'please_agree_to_terms_and_privacy' => 'Моля съгласете се с общите условия и политиката за поверителност за да създадете профил.',
    'i_agree_to_the' => 'Съгласявам се с',
    'terms_of_service_link' => 'условията за ползване',
    'privacy_policy_link' => 'политиката за поверителност',
    'view_website' => 'Виж уебсайт',
    'create_account' => 'Създай Профил',
    'email_login' => 'Влизане зрез email',
    'late_fees' => 'Закъснели Такси',
    'payment_number' => 'Номер на плащане',
    'before_due_date' => 'Преди крайната дата',
    'after_due_date' => 'След крайната дата',
    'after_invoice_date' => 'След датата на фактурата',
    'filtered_by_user' => 'Филтрирано по Потребител',
    'created_user' => 'Успешно създаден потребител',
    'primary_font' => 'Основен Шрифт',
    'secondary_font' => 'Допълнителен Шрифт',
    'number_padding' => 'Номер на отстояние',
    'general' => 'Общ',
    'surcharge_field' => 'Етикет допълнителна такса',
    'company_value' => 'Фирмена стойност',
    'credit_field' => 'Кредитно поле',
    'payment_field' => 'Поле за плащане',
    'group_field' => 'Поле за група',
    'number_counter' => 'Брояч на номера',
    'number_pattern' => 'Модел номер',
    'custom_javascript' => 'Персонализиран JavaScript',
    'portal_mode' => 'Портален режим',
    'attach_pdf' => 'Прикачване на PDF',
    'attach_documents' => 'Прикачване на Документи',
    'attach_ubl' => 'Прикачване на UBL',
    'email_style' => 'Стилове на имейла',
    'processed' => 'Обработен',
    'fee_amount' => 'Сума на таксата',
    'fee_percent' => 'Процент такса',
    'fee_cap' => 'Ограничение за такса',
    'limits_and_fees' => 'Лимити/Такси',
    'credentials' => 'Удостоверение за самоличност',
    'require_billing_address_help' => 'Изискване клиента да предостави адрес за фактуриране',
    'require_shipping_address_help' => 'Изискване клиента да предостави адрес за доставка',
    'deleted_tax_rate' => 'Успешно изтрита данъчна ставка',
    'restored_tax_rate' => 'Успешно възтановена данъчна ставка',
    'provider' => 'Доставчик',
    'company_gateway' => 'Портал за плащане',
    'company_gateways' => 'Портали за плащане',
    'new_company_gateway' => 'Нов портал',
    'edit_company_gateway' => 'Редактиране на портал',
    'created_company_gateway' => 'Успешно създаден портал',
    'updated_company_gateway' => 'Успешно актуализиран портал',
    'archived_company_gateway' => 'Успешно архивиране на портал',
    'deleted_company_gateway' => 'Успешно изтрит портал',
    'restored_company_gateway' => 'Успешно възстановен портал',
    'continue_editing' => 'Продължете редактирането',
    'default_value' => 'Стойност по подразбиране',
    'currency_format' => 'Формат на валутата',
    'first_day_of_the_week' => 'Първи ден от седмицата',
    'first_month_of_the_year' => 'Първи месец на годината',
    'symbol' => 'Символ',
    'ocde' => 'Код',
    'date_format' => 'Формат на датата',
    'datetime_format' => 'Формат за дата',
    'send_reminders' => 'Изпращане на напомняния',
    'timezone' => 'Часова зона',
    'filtered_by_group' => 'Филтрирано по група',
    'filtered_by_invoice' => 'Филтрирано по фактура',
    'filtered_by_client' => 'Филтрирано по клиент',
    'filtered_by_vendor' => 'Филтрирано по доставчик',
    'group_settings' => 'Настройки на групата',
    'groups' => 'Групи',
    'new_group' => 'Нова Група',
    'edit_group' => 'Редактира не Група',
    'created_group' => 'Групата беше създадена успешно',
    'updated_group' => 'Групата беше обновена успешно',
    'archived_group' => 'Групата беше архивирана успешно',
    'deleted_group' => 'Групата беше изтрита успешно',
    'restored_group' => 'Групата беше възстановена успешно',
    'upload_logo' => 'Качване на Лого',
    'uploaded_logo' => 'Логото беше качено успешно',
    'saved_settings' => 'Настройките бяха записани успешно',
    'device_settings' => 'Настройка на Устройство',
    'credit_cards_and_banks' => 'Кредитни Карти & Банки',
    'price' => 'Цена',
    'email_sign_up' => 'Регистрация с E-mail',
    'google_sign_up' => 'Регистрация с Google',
    'sign_up_with_google' => 'Регистриране с Google',
    'long_press_multiselect' => 'Натиснете дълго за мултиселекция',
    'migrate_to_next_version' => 'Минете към следващата версия на Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Миграция',
    'welcome_to_the_new_version' => 'Добре дошли в новата версия на Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Натиснете бутона отдолу за да свалите данните.',
    'migration_import' => 'Чудесно! Вече сте готови да внесете вашата миграция. Идете в новата инсталация за да внесете вашите данни',
    'continue' => 'Продължи',
    'company1' => 'Персонализирана Компания 1',
    'company2' => 'Персонализирана Компания 2',
    'company3' => 'Персонализирана Компания 3',
    'company4' => 'Персонализирана Компания 4',
    'product1' => 'Персонализиран Продукт 1',
    'product2' => 'Персонализиран Продукт 2',
    'product3' => 'Персонализиран Продукт 3',
    'product4' => 'Персонализиран Продукт 4',
    'client1' => 'Персонализиран клиент 1',
    'client2' => 'Персонализиран клиент 2',
    'client3' => 'Персонализиран клиент 3',
    'client4' => 'Персонализиран клиент 4',
    'contact1' => 'Персонализиран контакт 1',
    'contact2' => 'Персонализиран контакт 2',
    'contact3' => 'Персонализиран контакт 3',
    'contact4' => 'Персонализиран контакт 4',
    'task1' => 'Персонализирана задача 1',
    'task2' => 'Персонализирана задача 2',
    'task3' => 'Персонализирана задача 3',
    'task4' => 'Персонализирана задача 4',
    'project1' => 'Персонализиран проект 1',
    'project2' => 'Персонализиран проект 2',
    'project3' => 'Персонализиран проект 3',
    'project4' => 'Персонализиран проект 4',
    'expense1' => 'Персонализиран разход 1',
    'expense2' => 'Персонализиран разход 2',
    'expense3' => 'Персонализиран разход 3',
    'expense4' => 'Персонализиран разход 4',
    'vendor1' => 'Персонализиран доставчик 1',
    'vendor2' => 'Персонализиран доставчик 2',
    'vendor3' => 'Персонализиран доставчик 3',
    'vendor4' => 'Персонализиран доставчик 4',
    'invoice1' => 'Персонализирана фактура 1',
    'invoice2' => 'Персонализирана фактура 2',
    'invoice3' => 'Персонализирана фактура 3',
    'invoice4' => 'Персонализирана фактура 4',
    'payment1' => 'Персонализирано плащане 1',
    'payment2' => 'Персонализирано плащане 2',
    'payment3' => 'Персонализирано плащане 3',
    'payment4' => 'Персонализирано плащане 4',
    'surcharge1' => 'Персонализирано доплащане 1',
    'surcharge2' => 'Персонализирано доплащане 2',
    'surcharge3' => 'Персонализирано доплащане 3',
    'surcharge4' => 'Персонализирано доплащане 4',
    'group1' => 'Персонализирана група 1',
    'group2' => 'Персонализирана група 2',
    'group3' => 'Персонализирана група 3',
    'group4' => 'Персонализирана група 4',
    'number' => 'Номер',
    'count' => 'Брой',
    'is_active' => 'Е активен',
    'contact_last_login' => 'Последно влизане на контакта',
    'contact_full_name' => 'Пълно име на контакта',
    'contact_custom_value1' => 'Персонализирана контактна стойност 1',
    'contact_custom_value2' => 'Персонализирана контактна стойност 2',
    'contact_custom_value3' => 'Персонализирана контактна стойност 3',
    'contact_custom_value4' => 'Персонализирана контактна стойност 4',
    'assigned_to_id' => 'Присвоен на Id',
    'created_by_id' => 'Създаден от Id',
    'add_column' => 'Добави колона',
    'edit_columns' => 'Редактирай колони',
    'to_learn_about_gogle_fonts' => 'да научиш за Google шрифтовете',
    'refund_date' => 'Дата на възтановяване',
    'multiselect' => 'Мултиселекция',
    'verify_password' => 'Потвърди паролата',
    'applied' => 'Приложено',
    'include_recent_errors' => 'Включи последните грешки от логовете',
    'your_message_has_been_received' => 'Ние получихме съобщението Ви и ще се опитаме да отговорим незабавно.',
    'show_product_details' => 'Показване на детайлите на продукта',
    'show_product_details_help' => 'Включване на описанието и цената в падащото меню на продукта',
    'pdf_min_requirements' => 'PDF рендер-а изисква :version',
    'adjust_fee_percent' => 'Настойка на процент таксата',
    'configure_settings' => 'Конфигуриране на настройките',
    'about' => 'За',
    'credit_email' => 'Кредитен е-мейл',
    'domain_url' => 'Домейн адрес',
    'password_is_too_easy' => 'Паролата трябва да съдържа главна буква и цифра',
    'client_portal_tasks' => 'Задачи от клиентския портал',
    'client_portal_dashboard' => 'Табло на клиентския портал',
    'please_enter_a_value' => 'Моля въведете стойност',
    'deleted_logo' => 'Успешно изтрито лого',
    'generate_number' => 'Генерирай номер',
    'when_saved' => 'е запазена',
    'when_sent' => 'е изпратена',
    'select_company' => 'Избери компания',
    'float' => 'Плаващ',
    'collapse' => 'Събери',
    'show_or_hide' => 'Покажи/Скрий',
    'menu_sidebar' => 'Меню на страничната лента',
    'history_sidebar' => 'История на страничната лента',
    'tablet' => 'Таблет',
    'layout' => 'Оформление',
    'module' => 'Модул',
    'first_custom' => 'Първо персонализиране',
    'second_custom' => 'Второ персонализиране',
    'third_custom' => 'Трето персонализиране',
    'show_cost' => 'Показване на цена',
    'show_cost_help' => 'Покажи цената на продуктовото поле за да проследиш печалбата',
    'show_product_quantity' => 'Показване на продуктовата наличност',
    'show_product_quantity_help' => 'Покажи полето за наличност на продукта, или ще се използва стандартното поле',
    'show_invoice_quantity' => 'Покажи броят на фактурите',
    'show_invoice_quantity_help' => 'Покажи реда за наличност, или ще се използва стандартен ред',
    'default_quantity' => 'Наличност по подразбиране',
    'default_quantity_help' => 'Автоматично слагане на линията за наличност на едно',
    'one_tax_rate' => 'Една данъчна ставка',
    'two_tax_rates' => 'Две данъчни ставки',
    'three_tax_rates' => 'Три данъчни ставки',
    'default_tax_rate' => 'Данъчна ставка по подразбиране',
    'invoice_tax' => 'Такса за фактура',
    'line_item_tax' => 'Данък върху договорената покупка',
    'inclusive_taxes' => 'Включени такси',
    'invoice_tax_rates' => 'Данъчни ставки на фактури',
    'item_tax_rates' => 'Данъчни ставки',
    'configure_rates' => 'Конфигуриране на тарифите',
    'tax_settings_rates' => 'Размер на данъци',
    'accent_color' => 'Акцентен цвят',
    'comma_sparated_list' => 'Лист разделен със запетаи',
    'single_line_text' => 'Едноредов текст',
    'multi_line_text' => 'Многоредов текст',
    'dropdown' => 'Падащо меню',
    'field_type' => 'Вид поле',
    'recover_password_email_sent' => 'Изпратен е e-mail за възстановяване на парола',
    'removed_user' => 'Потребителя е премахнат успешно',
    'freq_three_years' => 'Три години',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Натиснете тук',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Фактурите са маркирани като изпратени',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'Системата не успя да изпрати фактура :invoice по e-mail',
    'custom_value3' => 'Персонифицирана стойност 3',
    'custom_value4' => 'Персонифицирана стойност 4',
    'email_style_custom' => 'Персонифициран стил на имейла',
    'custom_message_dashboard' => 'Персонифицирано съобщение на таблото',
    'custom_message_unpaid_invoice' => 'Персонифицирано съобшение за неплатена фактура',
    'custom_message_paid_invoice' => 'Персонифицирано съобшение за платена фактура',
    'custom_message_unapproved_quote' => 'Персонифицирано съобшение за непотвърдена фактура',
    'lock_sent_invoices' => 'Заключване на изпратените фактури',
    'translations' => 'Преводи',
    'task_number_pattern' => 'Задача номер',
    'task_number_counter' => 'Брояч на номер на задача',
    'expense_number_pattern' => 'Разход номер',
    'expense_number_counter' => 'Брояч на номер на разход',
    'vendor_number_pattern' => 'Номер на доставчик',
    'vendor_number_counter' => 'Брояч на номер на доставчик',
    'ticket_number_pattern' => 'Билет номер',
    'ticket_number_counter' => 'Брояч на номер на билет',
    'payment_number_pattern' => 'Номер на плащане',
    'payment_number_counter' => 'Брояч на номер на плащане',
    'invoice_number_pattern' => 'Номер на фактура',
    'quote_number_pattern' => 'Номер на оферта',
    'client_number_pattern' => 'Номер на кредит',
    'client_number_counter' => 'Брояч на номер на кредит',
    'credit_number_pattern' => 'Номер на кредит',
    'credit_number_counter' => 'Брояч на номер на кредит',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
